'use strict';

var web3_js = require('@solana/web3.js');

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();

// src/generated/errors/phoenixV1.ts
var PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS = 0;
var PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY = 1;
var PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT = 2;
var PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED = 3;
var PHOENIX_V1_ERROR__MARKET_UNINITIALIZED = 4;
var PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION = 5;
var PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER = 6;
var PHOENIX_V1_ERROR__INVALID_LOT_SIZE = 7;
var PHOENIX_V1_ERROR__INVALID_TICK_SIZE = 8;
var PHOENIX_V1_ERROR__INVALID_MINT = 9;
var PHOENIX_V1_ERROR__INVALID_BASE_VAULT = 10;
var PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT = 11;
var PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT = 12;
var PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT = 13;
var PHOENIX_V1_ERROR__TOO_MANY_EVENTS = 14;
var PHOENIX_V1_ERROR__NEW_ORDER_ERROR = 15;
var PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR = 16;
var PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR = 17;
var PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR = 18;
var PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR = 19;
var PHOENIX_V1_ERROR__TRADER_NOT_FOUND = 20;
var PHOENIX_V1_ERROR__INVALID_SEAT_STATUS = 21;
var PHOENIX_V1_ERROR__EVICTION_ERROR = 22;
var PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER = 23;
var PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT = 24;
var PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER = 25;
var phoenixV1ErrorMessages;
if (__DEV__) {
  phoenixV1ErrorMessages = {
    [PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR]: `Cancel multiple orders error`,
    [PHOENIX_V1_ERROR__EVICTION_ERROR]: `Failed to evict trader`,
    [PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER]: `Failed to flush buffer`,
    [PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT]: `Market deserialization error`,
    [PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT]: `Failed to serialize event`,
    [PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT]: `Invalid base account error`,
    [PHOENIX_V1_ERROR__INVALID_BASE_VAULT]: `Invalid base vault error`,
    [PHOENIX_V1_ERROR__INVALID_LOT_SIZE]: `Invalid lot size error`,
    [PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY]: `Invalid market authority error`,
    [PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS]: `Invalid market parameters error`,
    [PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER]: `Invalid market signer error`,
    [PHOENIX_V1_ERROR__INVALID_MINT]: `Invalid mint error`,
    [PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT]: `Invalid quote account error`,
    [PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT]: `Invalid quote vault error`,
    [PHOENIX_V1_ERROR__INVALID_SEAT_STATUS]: `Invalid seat status`,
    [PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION]: `Invalid state transition error`,
    [PHOENIX_V1_ERROR__INVALID_TICK_SIZE]: `Invalid tick size error`,
    [PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED]: `Market already initialized error`,
    [PHOENIX_V1_ERROR__MARKET_UNINITIALIZED]: `Market is not initialized error`,
    [PHOENIX_V1_ERROR__NEW_ORDER_ERROR]: `New order error`,
    [PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER]: `Non empty scratch buffer`,
    [PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR]: `Reduce order error`,
    [PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR]: `Remove empty orders error`,
    [PHOENIX_V1_ERROR__TOO_MANY_EVENTS]: `Too many events error`,
    [PHOENIX_V1_ERROR__TRADER_NOT_FOUND]: `Trader not found error`,
    [PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR]: `Withdraw funds error`
  };
}
function getPhoenixV1ErrorMessage(code) {
  if (__DEV__) {
    return phoenixV1ErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
var PHOENIX_V1_PROGRAM_ADDRESS = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
var PhoenixV1Instruction = /* @__PURE__ */ ((PhoenixV1Instruction2) => {
  PhoenixV1Instruction2[PhoenixV1Instruction2["Swap"] = 0] = "Swap";
  PhoenixV1Instruction2[PhoenixV1Instruction2["SwapWithFreeFunds"] = 1] = "SwapWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceLimitOrder"] = 2] = "PlaceLimitOrder";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceLimitOrderWithFreeFunds"] = 3] = "PlaceLimitOrderWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ReduceOrder"] = 4] = "ReduceOrder";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ReduceOrderWithFreeFunds"] = 5] = "ReduceOrderWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelAllOrders"] = 6] = "CancelAllOrders";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelAllOrdersWithFreeFunds"] = 7] = "CancelAllOrdersWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelUpTo"] = 8] = "CancelUpTo";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelUpToWithFreeFunds"] = 9] = "CancelUpToWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelMultipleOrdersById"] = 10] = "CancelMultipleOrdersById";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelMultipleOrdersByIdWithFreeFunds"] = 11] = "CancelMultipleOrdersByIdWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["WithdrawFunds"] = 12] = "WithdrawFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["DepositFunds"] = 13] = "DepositFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["RequestSeat"] = 14] = "RequestSeat";
  PhoenixV1Instruction2[PhoenixV1Instruction2["Log"] = 15] = "Log";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceMultiplePostOnlyOrders"] = 16] = "PlaceMultiplePostOnlyOrders";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceMultiplePostOnlyOrdersWithFreeFunds"] = 17] = "PlaceMultiplePostOnlyOrdersWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["InitializeMarket"] = 18] = "InitializeMarket";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ClaimAuthority"] = 19] = "ClaimAuthority";
  PhoenixV1Instruction2[PhoenixV1Instruction2["NameSuccessor"] = 20] = "NameSuccessor";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ChangeMarketStatus"] = 21] = "ChangeMarketStatus";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ChangeSeatStatus"] = 22] = "ChangeSeatStatus";
  PhoenixV1Instruction2[PhoenixV1Instruction2["RequestSeatAuthorized"] = 23] = "RequestSeatAuthorized";
  PhoenixV1Instruction2[PhoenixV1Instruction2["EvictSeat"] = 24] = "EvictSeat";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ForceCancelOrders"] = 25] = "ForceCancelOrders";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CollectFees"] = 26] = "CollectFees";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ChangeFeeRecipient"] = 27] = "ChangeFeeRecipient";
  return PhoenixV1Instruction2;
})(PhoenixV1Instruction || {});
function identifyPhoenixV1Instruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(0), 0)) {
    return 0 /* Swap */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(1), 0)) {
    return 1 /* SwapWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(2), 0)) {
    return 2 /* PlaceLimitOrder */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(3), 0)) {
    return 3 /* PlaceLimitOrderWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(4), 0)) {
    return 4 /* ReduceOrder */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(5), 0)) {
    return 5 /* ReduceOrderWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(6), 0)) {
    return 6 /* CancelAllOrders */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(7), 0)) {
    return 7 /* CancelAllOrdersWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(8), 0)) {
    return 8 /* CancelUpTo */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(9), 0)) {
    return 9 /* CancelUpToWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(10), 0)) {
    return 10 /* CancelMultipleOrdersById */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(11), 0)) {
    return 11 /* CancelMultipleOrdersByIdWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(12), 0)) {
    return 12 /* WithdrawFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(13), 0)) {
    return 13 /* DepositFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(14), 0)) {
    return 14 /* RequestSeat */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(15), 0)) {
    return 15 /* Log */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(16), 0)) {
    return 16 /* PlaceMultiplePostOnlyOrders */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(17), 0)) {
    return 17 /* PlaceMultiplePostOnlyOrdersWithFreeFunds */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(100), 0)) {
    return 18 /* InitializeMarket */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(101), 0)) {
    return 19 /* ClaimAuthority */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(102), 0)) {
    return 20 /* NameSuccessor */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(103), 0)) {
    return 21 /* ChangeMarketStatus */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(104), 0)) {
    return 22 /* ChangeSeatStatus */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(105), 0)) {
    return 23 /* RequestSeatAuthorized */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(106), 0)) {
    return 24 /* EvictSeat */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(107), 0)) {
    return 25 /* ForceCancelOrders */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(108), 0)) {
    return 26 /* CollectFees */;
  }
  if (web3_js.containsBytes(data, web3_js.getU8Encoder().encode(109), 0)) {
    return 27 /* ChangeFeeRecipient */;
  }
  throw new Error(
    "The provided instruction could not be identified as a phoenixV1 instruction."
  );
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: web3_js.AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? web3_js.AccountRole.WRITABLE : web3_js.AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? web3_js.upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && web3_js.isTransactionSigner(value);
}

// src/generated/instructions/cancelAllOrders.ts
function getCancelAllOrdersInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 6 })
  );
}
function getCancelAllOrdersInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCancelAllOrdersInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelAllOrdersInstructionDataEncoder(),
    getCancelAllOrdersInstructionDataDecoder()
  );
}
function getCancelAllOrdersInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCancelAllOrdersInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCancelAllOrdersInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCancelAllOrdersInstructionDataDecoder().decode(instruction.data)
  };
}
function getCancelAllOrdersWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 7 })
  );
}
function getCancelAllOrdersWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCancelAllOrdersWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelAllOrdersWithFreeFundsInstructionDataEncoder(),
    getCancelAllOrdersWithFreeFundsInstructionDataDecoder()
  );
}
function getCancelAllOrdersWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getCancelAllOrdersWithFreeFundsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCancelAllOrdersWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getCancelAllOrdersWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getAuditLogHeaderEncoder() {
  return web3_js.getStructEncoder([
    ["instruction", web3_js.getU8Encoder()],
    ["sequenceNumber", web3_js.getU64Encoder()],
    ["timestamp", web3_js.getI64Encoder()],
    ["slot", web3_js.getU64Encoder()],
    ["market", web3_js.getAddressEncoder()],
    ["signer", web3_js.getAddressEncoder()],
    ["totalEvents", web3_js.getU16Encoder()]
  ]);
}
function getAuditLogHeaderDecoder() {
  return web3_js.getStructDecoder([
    ["instruction", web3_js.getU8Decoder()],
    ["sequenceNumber", web3_js.getU64Decoder()],
    ["timestamp", web3_js.getI64Decoder()],
    ["slot", web3_js.getU64Decoder()],
    ["market", web3_js.getAddressDecoder()],
    ["signer", web3_js.getAddressDecoder()],
    ["totalEvents", web3_js.getU16Decoder()]
  ]);
}
function getAuditLogHeaderCodec() {
  return web3_js.combineCodec(getAuditLogHeaderEncoder(), getAuditLogHeaderDecoder());
}
function getCancelMultipleOrdersByIdParamsEncoder() {
  return web3_js.getStructEncoder([
    ["orders", web3_js.getArrayEncoder(getCancelOrderParamsEncoder())]
  ]);
}
function getCancelMultipleOrdersByIdParamsDecoder() {
  return web3_js.getStructDecoder([
    ["orders", web3_js.getArrayDecoder(getCancelOrderParamsDecoder())]
  ]);
}
function getCancelMultipleOrdersByIdParamsCodec() {
  return web3_js.combineCodec(
    getCancelMultipleOrdersByIdParamsEncoder(),
    getCancelMultipleOrdersByIdParamsDecoder()
  );
}
function getCancelOrderParamsEncoder() {
  return web3_js.getStructEncoder([
    ["side", getSideEncoder()],
    ["priceInTicks", web3_js.getU64Encoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()]
  ]);
}
function getCancelOrderParamsDecoder() {
  return web3_js.getStructDecoder([
    ["side", getSideDecoder()],
    ["priceInTicks", web3_js.getU64Decoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()]
  ]);
}
function getCancelOrderParamsCodec() {
  return web3_js.combineCodec(
    getCancelOrderParamsEncoder(),
    getCancelOrderParamsDecoder()
  );
}
function getCancelUpToParamsEncoder() {
  return web3_js.getStructEncoder([
    ["side", getSideEncoder()],
    ["tickLimit", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["numOrdersToSearch", web3_js.getOptionEncoder(web3_js.getU32Encoder())],
    ["numOrdersToCancel", web3_js.getOptionEncoder(web3_js.getU32Encoder())]
  ]);
}
function getCancelUpToParamsDecoder() {
  return web3_js.getStructDecoder([
    ["side", getSideDecoder()],
    ["tickLimit", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["numOrdersToSearch", web3_js.getOptionDecoder(web3_js.getU32Decoder())],
    ["numOrdersToCancel", web3_js.getOptionDecoder(web3_js.getU32Decoder())]
  ]);
}
function getCancelUpToParamsCodec() {
  return web3_js.combineCodec(
    getCancelUpToParamsEncoder(),
    getCancelUpToParamsDecoder()
  );
}
function getCondensedOrderEncoder() {
  return web3_js.getStructEncoder([
    ["priceInTicks", web3_js.getU64Encoder()],
    ["sizeInBaseLots", web3_js.getU64Encoder()],
    ["lastValidSlot", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
    ["lastValidUnixTimestampInSeconds", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
  ]);
}
function getCondensedOrderDecoder() {
  return web3_js.getStructDecoder([
    ["priceInTicks", web3_js.getU64Decoder()],
    ["sizeInBaseLots", web3_js.getU64Decoder()],
    ["lastValidSlot", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["lastValidUnixTimestampInSeconds", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getCondensedOrderCodec() {
  return web3_js.combineCodec(getCondensedOrderEncoder(), getCondensedOrderDecoder());
}
function getEvictEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["makerId", web3_js.getAddressEncoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()],
    ["priceInTicks", web3_js.getU64Encoder()],
    ["baseLotsEvicted", web3_js.getU64Encoder()]
  ]);
}
function getEvictEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["makerId", web3_js.getAddressDecoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()],
    ["priceInTicks", web3_js.getU64Decoder()],
    ["baseLotsEvicted", web3_js.getU64Decoder()]
  ]);
}
function getEvictEventCodec() {
  return web3_js.combineCodec(getEvictEventEncoder(), getEvictEventDecoder());
}
function getExpiredOrderEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["makerId", web3_js.getAddressEncoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()],
    ["priceInTicks", web3_js.getU64Encoder()],
    ["baseLotsRemoved", web3_js.getU64Encoder()]
  ]);
}
function getExpiredOrderEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["makerId", web3_js.getAddressDecoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()],
    ["priceInTicks", web3_js.getU64Decoder()],
    ["baseLotsRemoved", web3_js.getU64Decoder()]
  ]);
}
function getExpiredOrderEventCodec() {
  return web3_js.combineCodec(
    getExpiredOrderEventEncoder(),
    getExpiredOrderEventDecoder()
  );
}
var FailedMultipleLimitOrderBehavior = /* @__PURE__ */ ((FailedMultipleLimitOrderBehavior3) => {
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["FailOnInsufficientFundsAndAmendOnCross"] = 0] = "FailOnInsufficientFundsAndAmendOnCross";
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["FailOnInsufficientFundsAndFailOnCross"] = 1] = "FailOnInsufficientFundsAndFailOnCross";
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["SkipOnInsufficientFundsAndAmendOnCross"] = 2] = "SkipOnInsufficientFundsAndAmendOnCross";
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["SkipOnInsufficientFundsAndFailOnCross"] = 3] = "SkipOnInsufficientFundsAndFailOnCross";
  return FailedMultipleLimitOrderBehavior3;
})(FailedMultipleLimitOrderBehavior || {});
function getFailedMultipleLimitOrderBehaviorEncoder() {
  return web3_js.getEnumEncoder(FailedMultipleLimitOrderBehavior);
}
function getFailedMultipleLimitOrderBehaviorDecoder() {
  return web3_js.getEnumDecoder(FailedMultipleLimitOrderBehavior);
}
function getFailedMultipleLimitOrderBehaviorCodec() {
  return web3_js.combineCodec(
    getFailedMultipleLimitOrderBehaviorEncoder(),
    getFailedMultipleLimitOrderBehaviorDecoder()
  );
}
function getFeeEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["feesCollectedInQuoteLots", web3_js.getU64Encoder()]
  ]);
}
function getFeeEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["feesCollectedInQuoteLots", web3_js.getU64Decoder()]
  ]);
}
function getFeeEventCodec() {
  return web3_js.combineCodec(getFeeEventEncoder(), getFeeEventDecoder());
}
function getFIFOOrderIdEncoder() {
  return web3_js.getStructEncoder([
    ["priceInTicks", web3_js.getU64Encoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()]
  ]);
}
function getFIFOOrderIdDecoder() {
  return web3_js.getStructDecoder([
    ["priceInTicks", web3_js.getU64Decoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()]
  ]);
}
function getFIFOOrderIdCodec() {
  return web3_js.combineCodec(getFIFOOrderIdEncoder(), getFIFOOrderIdDecoder());
}
function getFillEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["makerId", web3_js.getAddressEncoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()],
    ["priceInTicks", web3_js.getU64Encoder()],
    ["baseLotsFilled", web3_js.getU64Encoder()],
    ["baseLotsRemaining", web3_js.getU64Encoder()]
  ]);
}
function getFillEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["makerId", web3_js.getAddressDecoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()],
    ["priceInTicks", web3_js.getU64Decoder()],
    ["baseLotsFilled", web3_js.getU64Decoder()],
    ["baseLotsRemaining", web3_js.getU64Decoder()]
  ]);
}
function getFillEventCodec() {
  return web3_js.combineCodec(getFillEventEncoder(), getFillEventDecoder());
}
function getFillSummaryEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["clientOrderId", web3_js.getU128Encoder()],
    ["totalBaseLotsFilled", web3_js.getU64Encoder()],
    ["totalQuoteLotsFilled", web3_js.getU64Encoder()],
    ["totalFeeInQuoteLots", web3_js.getU64Encoder()]
  ]);
}
function getFillSummaryEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["clientOrderId", web3_js.getU128Decoder()],
    ["totalBaseLotsFilled", web3_js.getU64Decoder()],
    ["totalQuoteLotsFilled", web3_js.getU64Decoder()],
    ["totalFeeInQuoteLots", web3_js.getU64Decoder()]
  ]);
}
function getFillSummaryEventCodec() {
  return web3_js.combineCodec(
    getFillSummaryEventEncoder(),
    getFillSummaryEventDecoder()
  );
}
function getMarketHeaderEncoder() {
  return web3_js.getStructEncoder([
    ["discriminant", web3_js.getU64Encoder()],
    ["status", web3_js.getU64Encoder()],
    ["marketSizeParams", getMarketSizeParamsEncoder()],
    ["baseParams", getTokenParamsEncoder()],
    ["baseLotSize", web3_js.getU64Encoder()],
    ["quoteParams", getTokenParamsEncoder()],
    ["quoteLotSize", web3_js.getU64Encoder()],
    ["tickSizeInQuoteAtomsPerBaseUnit", web3_js.getU64Encoder()],
    ["authority", web3_js.getAddressEncoder()],
    ["feeRecipient", web3_js.getAddressEncoder()],
    ["marketSequenceNumber", web3_js.getU64Encoder()],
    ["successor", web3_js.getAddressEncoder()],
    ["rawBaseUnitsPerBaseUnit", web3_js.getU32Encoder()],
    ["padding1", web3_js.getU32Encoder()],
    ["padding2", web3_js.getArrayEncoder(web3_js.getU64Encoder(), { size: 32 })]
  ]);
}
function getMarketHeaderDecoder() {
  return web3_js.getStructDecoder([
    ["discriminant", web3_js.getU64Decoder()],
    ["status", web3_js.getU64Decoder()],
    ["marketSizeParams", getMarketSizeParamsDecoder()],
    ["baseParams", getTokenParamsDecoder()],
    ["baseLotSize", web3_js.getU64Decoder()],
    ["quoteParams", getTokenParamsDecoder()],
    ["quoteLotSize", web3_js.getU64Decoder()],
    ["tickSizeInQuoteAtomsPerBaseUnit", web3_js.getU64Decoder()],
    ["authority", web3_js.getAddressDecoder()],
    ["feeRecipient", web3_js.getAddressDecoder()],
    ["marketSequenceNumber", web3_js.getU64Decoder()],
    ["successor", web3_js.getAddressDecoder()],
    ["rawBaseUnitsPerBaseUnit", web3_js.getU32Decoder()],
    ["padding1", web3_js.getU32Decoder()],
    ["padding2", web3_js.getArrayDecoder(web3_js.getU64Decoder(), { size: 32 })]
  ]);
}
function getMarketHeaderCodec() {
  return web3_js.combineCodec(getMarketHeaderEncoder(), getMarketHeaderDecoder());
}
function getMarketSizeParamsEncoder() {
  return web3_js.getStructEncoder([
    ["bidsSize", web3_js.getU64Encoder()],
    ["asksSize", web3_js.getU64Encoder()],
    ["numSeats", web3_js.getU64Encoder()]
  ]);
}
function getMarketSizeParamsDecoder() {
  return web3_js.getStructDecoder([
    ["bidsSize", web3_js.getU64Decoder()],
    ["asksSize", web3_js.getU64Decoder()],
    ["numSeats", web3_js.getU64Decoder()]
  ]);
}
function getMarketSizeParamsCodec() {
  return web3_js.combineCodec(
    getMarketSizeParamsEncoder(),
    getMarketSizeParamsDecoder()
  );
}
var MarketStatus = /* @__PURE__ */ ((MarketStatus3) => {
  MarketStatus3[MarketStatus3["Uninitialized"] = 0] = "Uninitialized";
  MarketStatus3[MarketStatus3["Active"] = 1] = "Active";
  MarketStatus3[MarketStatus3["PostOnly"] = 2] = "PostOnly";
  MarketStatus3[MarketStatus3["Paused"] = 3] = "Paused";
  MarketStatus3[MarketStatus3["Closed"] = 4] = "Closed";
  MarketStatus3[MarketStatus3["Tombstoned"] = 5] = "Tombstoned";
  return MarketStatus3;
})(MarketStatus || {});
function getMarketStatusEncoder() {
  return web3_js.getEnumEncoder(MarketStatus);
}
function getMarketStatusDecoder() {
  return web3_js.getEnumDecoder(MarketStatus);
}
function getMarketStatusCodec() {
  return web3_js.combineCodec(getMarketStatusEncoder(), getMarketStatusDecoder());
}
function getMultipleOrderPacketEncoder() {
  return web3_js.getStructEncoder([
    ["bids", web3_js.getArrayEncoder(getCondensedOrderEncoder())],
    ["asks", web3_js.getArrayEncoder(getCondensedOrderEncoder())],
    ["clientOrderId", web3_js.getOptionEncoder(web3_js.getU128Encoder())],
    [
      "failedMultipleLimitOrderBehavior",
      getFailedMultipleLimitOrderBehaviorEncoder()
    ]
  ]);
}
function getMultipleOrderPacketDecoder() {
  return web3_js.getStructDecoder([
    ["bids", web3_js.getArrayDecoder(getCondensedOrderDecoder())],
    ["asks", web3_js.getArrayDecoder(getCondensedOrderDecoder())],
    ["clientOrderId", web3_js.getOptionDecoder(web3_js.getU128Decoder())],
    [
      "failedMultipleLimitOrderBehavior",
      getFailedMultipleLimitOrderBehaviorDecoder()
    ]
  ]);
}
function getMultipleOrderPacketCodec() {
  return web3_js.combineCodec(
    getMultipleOrderPacketEncoder(),
    getMultipleOrderPacketDecoder()
  );
}
function getOrderPacketEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    [
      "PostOnly",
      web3_js.getStructEncoder([
        ["side", getSideEncoder()],
        ["priceInTicks", web3_js.getU64Encoder()],
        ["numBaseLots", web3_js.getU64Encoder()],
        ["clientOrderId", web3_js.getU128Encoder()],
        ["rejectPostOnly", web3_js.getBooleanEncoder()],
        ["useOnlyDepositedFunds", web3_js.getBooleanEncoder()],
        ["lastValidSlot", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["lastValidUnixTimestampInSeconds", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["failSilentlyOnInsufficientFunds", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "Limit",
      web3_js.getStructEncoder([
        ["side", getSideEncoder()],
        ["priceInTicks", web3_js.getU64Encoder()],
        ["numBaseLots", web3_js.getU64Encoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorEncoder()],
        ["matchLimit", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["clientOrderId", web3_js.getU128Encoder()],
        ["useOnlyDepositedFunds", web3_js.getBooleanEncoder()],
        ["lastValidSlot", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["lastValidUnixTimestampInSeconds", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["failSilentlyOnInsufficientFunds", web3_js.getBooleanEncoder()]
      ])
    ],
    [
      "ImmediateOrCancel",
      web3_js.getStructEncoder([
        ["side", getSideEncoder()],
        ["priceInTicks", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["numBaseLots", web3_js.getU64Encoder()],
        ["numQuoteLots", web3_js.getU64Encoder()],
        ["minBaseLotsToFill", web3_js.getU64Encoder()],
        ["minQuoteLotsToFill", web3_js.getU64Encoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorEncoder()],
        ["matchLimit", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["clientOrderId", web3_js.getU128Encoder()],
        ["useOnlyDepositedFunds", web3_js.getBooleanEncoder()],
        ["lastValidSlot", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
        ["lastValidUnixTimestampInSeconds", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
      ])
    ]
  ]);
}
function getOrderPacketDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    [
      "PostOnly",
      web3_js.getStructDecoder([
        ["side", getSideDecoder()],
        ["priceInTicks", web3_js.getU64Decoder()],
        ["numBaseLots", web3_js.getU64Decoder()],
        ["clientOrderId", web3_js.getU128Decoder()],
        ["rejectPostOnly", web3_js.getBooleanDecoder()],
        ["useOnlyDepositedFunds", web3_js.getBooleanDecoder()],
        ["lastValidSlot", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["lastValidUnixTimestampInSeconds", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["failSilentlyOnInsufficientFunds", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "Limit",
      web3_js.getStructDecoder([
        ["side", getSideDecoder()],
        ["priceInTicks", web3_js.getU64Decoder()],
        ["numBaseLots", web3_js.getU64Decoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorDecoder()],
        ["matchLimit", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["clientOrderId", web3_js.getU128Decoder()],
        ["useOnlyDepositedFunds", web3_js.getBooleanDecoder()],
        ["lastValidSlot", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["lastValidUnixTimestampInSeconds", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["failSilentlyOnInsufficientFunds", web3_js.getBooleanDecoder()]
      ])
    ],
    [
      "ImmediateOrCancel",
      web3_js.getStructDecoder([
        ["side", getSideDecoder()],
        ["priceInTicks", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["numBaseLots", web3_js.getU64Decoder()],
        ["numQuoteLots", web3_js.getU64Decoder()],
        ["minBaseLotsToFill", web3_js.getU64Decoder()],
        ["minQuoteLotsToFill", web3_js.getU64Decoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorDecoder()],
        ["matchLimit", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["clientOrderId", web3_js.getU128Decoder()],
        ["useOnlyDepositedFunds", web3_js.getBooleanDecoder()],
        ["lastValidSlot", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
        ["lastValidUnixTimestampInSeconds", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
      ])
    ]
  ]);
}
function getOrderPacketCodec() {
  return web3_js.combineCodec(getOrderPacketEncoder(), getOrderPacketDecoder());
}
function orderPacket(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isOrderPacket(kind, value) {
  return value.__kind === kind;
}
function getPhoenixMarketEventEncoder() {
  return web3_js.getDiscriminatedUnionEncoder([
    ["Uninitialized", web3_js.getUnitEncoder()],
    [
      "Header",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getAuditLogHeaderEncoder()])]
      ])
    ],
    [
      "Fill",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getFillEventEncoder()])]])
    ],
    [
      "Place",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getPlaceEventEncoder()])]])
    ],
    [
      "Reduce",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getReduceEventEncoder()])]
      ])
    ],
    [
      "Evict",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getEvictEventEncoder()])]])
    ],
    [
      "FillSummary",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getFillSummaryEventEncoder()])]
      ])
    ],
    [
      "Fee",
      web3_js.getStructEncoder([["fields", web3_js.getTupleEncoder([getFeeEventEncoder()])]])
    ],
    [
      "TimeInForce",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getTimeInForceEventEncoder()])]
      ])
    ],
    [
      "ExpiredOrder",
      web3_js.getStructEncoder([
        ["fields", web3_js.getTupleEncoder([getExpiredOrderEventEncoder()])]
      ])
    ]
  ]);
}
function getPhoenixMarketEventDecoder() {
  return web3_js.getDiscriminatedUnionDecoder([
    ["Uninitialized", web3_js.getUnitDecoder()],
    [
      "Header",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getAuditLogHeaderDecoder()])]
      ])
    ],
    [
      "Fill",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getFillEventDecoder()])]])
    ],
    [
      "Place",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getPlaceEventDecoder()])]])
    ],
    [
      "Reduce",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getReduceEventDecoder()])]
      ])
    ],
    [
      "Evict",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getEvictEventDecoder()])]])
    ],
    [
      "FillSummary",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getFillSummaryEventDecoder()])]
      ])
    ],
    [
      "Fee",
      web3_js.getStructDecoder([["fields", web3_js.getTupleDecoder([getFeeEventDecoder()])]])
    ],
    [
      "TimeInForce",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getTimeInForceEventDecoder()])]
      ])
    ],
    [
      "ExpiredOrder",
      web3_js.getStructDecoder([
        ["fields", web3_js.getTupleDecoder([getExpiredOrderEventDecoder()])]
      ])
    ]
  ]);
}
function getPhoenixMarketEventCodec() {
  return web3_js.combineCodec(
    getPhoenixMarketEventEncoder(),
    getPhoenixMarketEventDecoder()
  );
}
function phoenixMarketEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPhoenixMarketEvent(kind, value) {
  return value.__kind === kind;
}
function getPlaceEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()],
    ["clientOrderId", web3_js.getU128Encoder()],
    ["priceInTicks", web3_js.getU64Encoder()],
    ["baseLotsPlaced", web3_js.getU64Encoder()]
  ]);
}
function getPlaceEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()],
    ["clientOrderId", web3_js.getU128Decoder()],
    ["priceInTicks", web3_js.getU64Decoder()],
    ["baseLotsPlaced", web3_js.getU64Decoder()]
  ]);
}
function getPlaceEventCodec() {
  return web3_js.combineCodec(getPlaceEventEncoder(), getPlaceEventDecoder());
}
function getReduceEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()],
    ["priceInTicks", web3_js.getU64Encoder()],
    ["baseLotsRemoved", web3_js.getU64Encoder()],
    ["baseLotsRemaining", web3_js.getU64Encoder()]
  ]);
}
function getReduceEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()],
    ["priceInTicks", web3_js.getU64Decoder()],
    ["baseLotsRemoved", web3_js.getU64Decoder()],
    ["baseLotsRemaining", web3_js.getU64Decoder()]
  ]);
}
function getReduceEventCodec() {
  return web3_js.combineCodec(getReduceEventEncoder(), getReduceEventDecoder());
}
function getReduceOrderParamsEncoder() {
  return web3_js.getStructEncoder([
    ["baseParams", getCancelOrderParamsEncoder()],
    ["size", web3_js.getU64Encoder()]
  ]);
}
function getReduceOrderParamsDecoder() {
  return web3_js.getStructDecoder([
    ["baseParams", getCancelOrderParamsDecoder()],
    ["size", web3_js.getU64Decoder()]
  ]);
}
function getReduceOrderParamsCodec() {
  return web3_js.combineCodec(
    getReduceOrderParamsEncoder(),
    getReduceOrderParamsDecoder()
  );
}
function getSeatEncoder() {
  return web3_js.getStructEncoder([
    ["discriminant", web3_js.getU64Encoder()],
    ["market", web3_js.getAddressEncoder()],
    ["trader", web3_js.getAddressEncoder()],
    ["approvalStatus", web3_js.getU64Encoder()],
    ["padding", web3_js.getArrayEncoder(web3_js.getU64Encoder(), { size: 6 })]
  ]);
}
function getSeatDecoder() {
  return web3_js.getStructDecoder([
    ["discriminant", web3_js.getU64Decoder()],
    ["market", web3_js.getAddressDecoder()],
    ["trader", web3_js.getAddressDecoder()],
    ["approvalStatus", web3_js.getU64Decoder()],
    ["padding", web3_js.getArrayDecoder(web3_js.getU64Decoder(), { size: 6 })]
  ]);
}
function getSeatCodec() {
  return web3_js.combineCodec(getSeatEncoder(), getSeatDecoder());
}
var SeatApprovalStatus = /* @__PURE__ */ ((SeatApprovalStatus3) => {
  SeatApprovalStatus3[SeatApprovalStatus3["NotApproved"] = 0] = "NotApproved";
  SeatApprovalStatus3[SeatApprovalStatus3["Approved"] = 1] = "Approved";
  SeatApprovalStatus3[SeatApprovalStatus3["Retired"] = 2] = "Retired";
  return SeatApprovalStatus3;
})(SeatApprovalStatus || {});
function getSeatApprovalStatusEncoder() {
  return web3_js.getEnumEncoder(SeatApprovalStatus);
}
function getSeatApprovalStatusDecoder() {
  return web3_js.getEnumDecoder(SeatApprovalStatus);
}
function getSeatApprovalStatusCodec() {
  return web3_js.combineCodec(
    getSeatApprovalStatusEncoder(),
    getSeatApprovalStatusDecoder()
  );
}
var SelfTradeBehavior2 = /* @__PURE__ */ ((SelfTradeBehavior3) => {
  SelfTradeBehavior3[SelfTradeBehavior3["Abort"] = 0] = "Abort";
  SelfTradeBehavior3[SelfTradeBehavior3["CancelProvide"] = 1] = "CancelProvide";
  SelfTradeBehavior3[SelfTradeBehavior3["DecrementTake"] = 2] = "DecrementTake";
  return SelfTradeBehavior3;
})(SelfTradeBehavior2 || {});
function getSelfTradeBehaviorEncoder() {
  return web3_js.getEnumEncoder(SelfTradeBehavior2);
}
function getSelfTradeBehaviorDecoder() {
  return web3_js.getEnumDecoder(SelfTradeBehavior2);
}
function getSelfTradeBehaviorCodec() {
  return web3_js.combineCodec(
    getSelfTradeBehaviorEncoder(),
    getSelfTradeBehaviorDecoder()
  );
}
var Side4 = /* @__PURE__ */ ((Side5) => {
  Side5[Side5["Bid"] = 0] = "Bid";
  Side5[Side5["Ask"] = 1] = "Ask";
  return Side5;
})(Side4 || {});
function getSideEncoder() {
  return web3_js.getEnumEncoder(Side4);
}
function getSideDecoder() {
  return web3_js.getEnumDecoder(Side4);
}
function getSideCodec() {
  return web3_js.combineCodec(getSideEncoder(), getSideDecoder());
}
function getTimeInForceEventEncoder() {
  return web3_js.getStructEncoder([
    ["index", web3_js.getU16Encoder()],
    ["orderSequenceNumber", web3_js.getU64Encoder()],
    ["lastValidSlot", web3_js.getU64Encoder()],
    ["lastValidUnixTimestampInSeconds", web3_js.getU64Encoder()]
  ]);
}
function getTimeInForceEventDecoder() {
  return web3_js.getStructDecoder([
    ["index", web3_js.getU16Decoder()],
    ["orderSequenceNumber", web3_js.getU64Decoder()],
    ["lastValidSlot", web3_js.getU64Decoder()],
    ["lastValidUnixTimestampInSeconds", web3_js.getU64Decoder()]
  ]);
}
function getTimeInForceEventCodec() {
  return web3_js.combineCodec(
    getTimeInForceEventEncoder(),
    getTimeInForceEventDecoder()
  );
}
function getTokenParamsEncoder() {
  return web3_js.getStructEncoder([
    ["decimals", web3_js.getU32Encoder()],
    ["vaultBump", web3_js.getU32Encoder()],
    ["mintKey", web3_js.getAddressEncoder()],
    ["vaultKey", web3_js.getAddressEncoder()]
  ]);
}
function getTokenParamsDecoder() {
  return web3_js.getStructDecoder([
    ["decimals", web3_js.getU32Decoder()],
    ["vaultBump", web3_js.getU32Decoder()],
    ["mintKey", web3_js.getAddressDecoder()],
    ["vaultKey", web3_js.getAddressDecoder()]
  ]);
}
function getTokenParamsCodec() {
  return web3_js.combineCodec(getTokenParamsEncoder(), getTokenParamsDecoder());
}

// src/generated/instructions/cancelMultipleOrdersById.ts
function getCancelMultipleOrdersByIdInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getCancelMultipleOrdersByIdParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 10 })
  );
}
function getCancelMultipleOrdersByIdInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getCancelMultipleOrdersByIdParamsDecoder()]
  ]);
}
function getCancelMultipleOrdersByIdInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelMultipleOrdersByIdInstructionDataEncoder(),
    getCancelMultipleOrdersByIdInstructionDataDecoder()
  );
}
function getCancelMultipleOrdersByIdInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCancelMultipleOrdersByIdInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelMultipleOrdersByIdInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCancelMultipleOrdersByIdInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getCancelMultipleOrdersByIdParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 11 })
  );
}
function getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getCancelMultipleOrdersByIdParamsDecoder()]
  ]);
}
function getCancelMultipleOrdersByIdWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder(),
    getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder()
  );
}
function getCancelMultipleOrdersByIdWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelMultipleOrdersByIdWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCancelUpToInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getCancelUpToParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 8 })
  );
}
function getCancelUpToInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getCancelUpToParamsDecoder()]
  ]);
}
function getCancelUpToInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelUpToInstructionDataEncoder(),
    getCancelUpToInstructionDataDecoder()
  );
}
function getCancelUpToInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCancelUpToInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelUpToInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCancelUpToInstructionDataDecoder().decode(instruction.data)
  };
}
function getCancelUpToWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getCancelUpToParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 9 })
  );
}
function getCancelUpToWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getCancelUpToParamsDecoder()]
  ]);
}
function getCancelUpToWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getCancelUpToWithFreeFundsInstructionDataEncoder(),
    getCancelUpToWithFreeFundsInstructionDataDecoder()
  );
}
function getCancelUpToWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getCancelUpToWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelUpToWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getCancelUpToWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getChangeFeeRecipientInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 109 })
  );
}
function getChangeFeeRecipientInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getChangeFeeRecipientInstructionDataCodec() {
  return web3_js.combineCodec(
    getChangeFeeRecipientInstructionDataEncoder(),
    getChangeFeeRecipientInstructionDataDecoder()
  );
}
function getChangeFeeRecipientInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    newFeeRecipient: {
      value: input.newFeeRecipient ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.newFeeRecipient)
    ],
    programAddress,
    data: getChangeFeeRecipientInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseChangeFeeRecipientInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      newFeeRecipient: getNextAccount()
    },
    data: getChangeFeeRecipientInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getChangeMarketStatusInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["marketStatus", getMarketStatusEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 103 })
  );
}
function getChangeMarketStatusInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["marketStatus", getMarketStatusDecoder()]
  ]);
}
function getChangeMarketStatusInstructionDataCodec() {
  return web3_js.combineCodec(
    getChangeMarketStatusInstructionDataEncoder(),
    getChangeMarketStatusInstructionDataDecoder()
  );
}
function getChangeMarketStatusInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority)
    ],
    programAddress,
    data: getChangeMarketStatusInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseChangeMarketStatusInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount()
    },
    data: getChangeMarketStatusInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getChangeSeatStatusInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["approvalStatus", getSeatApprovalStatusEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 104 })
  );
}
function getChangeSeatStatusInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["approvalStatus", getSeatApprovalStatusDecoder()]
  ]);
}
function getChangeSeatStatusInstructionDataCodec() {
  return web3_js.combineCodec(
    getChangeSeatStatusInstructionDataEncoder(),
    getChangeSeatStatusInstructionDataDecoder()
  );
}
function getChangeSeatStatusInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    seat: { value: input.seat ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getChangeSeatStatusInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseChangeSeatStatusInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      seat: getNextAccount()
    },
    data: getChangeSeatStatusInstructionDataDecoder().decode(instruction.data)
  };
}
function getClaimAuthorityInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 101 })
  );
}
function getClaimAuthorityInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getClaimAuthorityInstructionDataCodec() {
  return web3_js.combineCodec(
    getClaimAuthorityInstructionDataEncoder(),
    getClaimAuthorityInstructionDataDecoder()
  );
}
function getClaimAuthorityInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    successor: { value: input.successor ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.successor)
    ],
    programAddress,
    data: getClaimAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseClaimAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      successor: getNextAccount()
    },
    data: getClaimAuthorityInstructionDataDecoder().decode(instruction.data)
  };
}
function getCollectFeesInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 108 })
  );
}
function getCollectFeesInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getCollectFeesInstructionDataCodec() {
  return web3_js.combineCodec(
    getCollectFeesInstructionDataEncoder(),
    getCollectFeesInstructionDataDecoder()
  );
}
function getCollectFeesInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    sweeper: { value: input.sweeper ?? null, isWritable: false },
    feeRecipient: { value: input.feeRecipient ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.sweeper),
      getAccountMeta(accounts.feeRecipient),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCollectFeesInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCollectFeesInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      sweeper: getNextAccount(),
      feeRecipient: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCollectFeesInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["quoteLotsToDeposit", web3_js.getU64Encoder()],
      ["baseLotsToDeposit", web3_js.getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 13 })
  );
}
function getDepositFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["quoteLotsToDeposit", web3_js.getU64Decoder()],
    ["baseLotsToDeposit", web3_js.getU64Decoder()]
  ]);
}
function getDepositFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getDepositFundsInstructionDataEncoder(),
    getDepositFundsInstructionDataDecoder()
  );
}
function getDepositFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getDepositFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositFundsInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getDepositFundsInstructionDataDecoder().decode(instruction.data)
  };
}
function getEvictSeatInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 106 })
  );
}
function getEvictSeatInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getEvictSeatInstructionDataCodec() {
  return web3_js.combineCodec(
    getEvictSeatInstructionDataEncoder(),
    getEvictSeatInstructionDataDecoder()
  );
}
function getEvictSeatInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getEvictSeatInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseEvictSeatInstruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getEvictSeatInstructionDataDecoder().decode(instruction.data)
  };
}
function getForceCancelOrdersInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getCancelUpToParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 107 })
  );
}
function getForceCancelOrdersInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getCancelUpToParamsDecoder()]
  ]);
}
function getForceCancelOrdersInstructionDataCodec() {
  return web3_js.combineCodec(
    getForceCancelOrdersInstructionDataEncoder(),
    getForceCancelOrdersInstructionDataDecoder()
  );
}
function getForceCancelOrdersInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getForceCancelOrdersInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseForceCancelOrdersInstruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getForceCancelOrdersInstructionDataDecoder().decode(instruction.data)
  };
}
function getInitializeMarketInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["marketSizeParams", getMarketSizeParamsEncoder()],
      ["numQuoteLotsPerQuoteUnit", web3_js.getU64Encoder()],
      ["tickSizeInQuoteLotsPerBaseUnit", web3_js.getU64Encoder()],
      ["numBaseLotsPerBaseUnit", web3_js.getU64Encoder()],
      ["takerFeeBps", web3_js.getU16Encoder()],
      ["feeCollector", web3_js.getAddressEncoder()],
      ["rawBaseUnitsPerBaseUnit", web3_js.getOptionEncoder(web3_js.getU32Encoder())]
    ]),
    (value) => ({ ...value, discriminator: 100 })
  );
}
function getInitializeMarketInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["marketSizeParams", getMarketSizeParamsDecoder()],
    ["numQuoteLotsPerQuoteUnit", web3_js.getU64Decoder()],
    ["tickSizeInQuoteLotsPerBaseUnit", web3_js.getU64Decoder()],
    ["numBaseLotsPerBaseUnit", web3_js.getU64Decoder()],
    ["takerFeeBps", web3_js.getU16Decoder()],
    ["feeCollector", web3_js.getAddressDecoder()],
    ["rawBaseUnitsPerBaseUnit", web3_js.getOptionDecoder(web3_js.getU32Decoder())]
  ]);
}
function getInitializeMarketInstructionDataCodec() {
  return web3_js.combineCodec(
    getInitializeMarketInstructionDataEncoder(),
    getInitializeMarketInstructionDataDecoder()
  );
}
function getInitializeMarketInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketCreator: { value: input.marketCreator ?? null, isWritable: true },
    baseMint: { value: input.baseMint ?? null, isWritable: false },
    quoteMint: { value: input.quoteMint ?? null, isWritable: false },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketCreator),
      getAccountMeta(accounts.baseMint),
      getAccountMeta(accounts.quoteMint),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getInitializeMarketInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitializeMarketInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketCreator: getNextAccount(),
      baseMint: getNextAccount(),
      quoteMint: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getInitializeMarketInstructionDataDecoder().decode(instruction.data)
  };
}
function getLogInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 15 })
  );
}
function getLogInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getLogInstructionDataCodec() {
  return web3_js.combineCodec(
    getLogInstructionDataEncoder(),
    getLogInstructionDataDecoder()
  );
}
function getLogInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    logAuthority: { value: input.logAuthority ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [getAccountMeta(accounts.logAuthority)],
    programAddress,
    data: getLogInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseLogInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      logAuthority: getNextAccount()
    },
    data: getLogInstructionDataDecoder().decode(instruction.data)
  };
}
function getNameSuccessorInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["successor", web3_js.getAddressEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 102 })
  );
}
function getNameSuccessorInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["successor", web3_js.getAddressDecoder()]
  ]);
}
function getNameSuccessorInstructionDataCodec() {
  return web3_js.combineCodec(
    getNameSuccessorInstructionDataEncoder(),
    getNameSuccessorInstructionDataDecoder()
  );
}
function getNameSuccessorInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority)
    ],
    programAddress,
    data: getNameSuccessorInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseNameSuccessorInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount()
    },
    data: getNameSuccessorInstructionDataDecoder().decode(instruction.data)
  };
}
function getPlaceLimitOrderInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 2 })
  );
}
function getPlaceLimitOrderInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getPlaceLimitOrderInstructionDataCodec() {
  return web3_js.combineCodec(
    getPlaceLimitOrderInstructionDataEncoder(),
    getPlaceLimitOrderInstructionDataDecoder()
  );
}
function getPlaceLimitOrderInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getPlaceLimitOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceLimitOrderInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getPlaceLimitOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getPlaceLimitOrderWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 3 })
  );
}
function getPlaceLimitOrderWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getPlaceLimitOrderWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getPlaceLimitOrderWithFreeFundsInstructionDataEncoder(),
    getPlaceLimitOrderWithFreeFundsInstructionDataDecoder()
  );
}
function getPlaceLimitOrderWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getPlaceLimitOrderWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceLimitOrderWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount()
    },
    data: getPlaceLimitOrderWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getPlaceMultiplePostOnlyOrdersInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["multipleOrderPacket", getMultipleOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 16 })
  );
}
function getPlaceMultiplePostOnlyOrdersInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["multipleOrderPacket", getMultipleOrderPacketDecoder()]
  ]);
}
function getPlaceMultiplePostOnlyOrdersInstructionDataCodec() {
  return web3_js.combineCodec(
    getPlaceMultiplePostOnlyOrdersInstructionDataEncoder(),
    getPlaceMultiplePostOnlyOrdersInstructionDataDecoder()
  );
}
function getPlaceMultiplePostOnlyOrdersInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getPlaceMultiplePostOnlyOrdersInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceMultiplePostOnlyOrdersInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getPlaceMultiplePostOnlyOrdersInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["multipleOrderPacket", getMultipleOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 17 })
  );
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["multipleOrderPacket", getMultipleOrderPacketDecoder()]
  ]);
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder(),
    getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder()
  );
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceMultiplePostOnlyOrdersWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount()
    },
    data: getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getReduceOrderInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getReduceOrderParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 4 })
  );
}
function getReduceOrderInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getReduceOrderParamsDecoder()]
  ]);
}
function getReduceOrderInstructionDataCodec() {
  return web3_js.combineCodec(
    getReduceOrderInstructionDataEncoder(),
    getReduceOrderInstructionDataDecoder()
  );
}
function getReduceOrderInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getReduceOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseReduceOrderInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getReduceOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getReduceOrderWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["params", getReduceOrderParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 5 })
  );
}
function getReduceOrderWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["params", getReduceOrderParamsDecoder()]
  ]);
}
function getReduceOrderWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getReduceOrderWithFreeFundsInstructionDataEncoder(),
    getReduceOrderWithFreeFundsInstructionDataDecoder()
  );
}
function getReduceOrderWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getReduceOrderWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseReduceOrderWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getReduceOrderWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getRequestSeatInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 14 })
  );
}
function getRequestSeatInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getRequestSeatInstructionDataCodec() {
  return web3_js.combineCodec(
    getRequestSeatInstructionDataEncoder(),
    getRequestSeatInstructionDataDecoder()
  );
}
function getRequestSeatInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    seat: { value: input.seat ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getRequestSeatInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRequestSeatInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      payer: getNextAccount(),
      seat: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getRequestSeatInstructionDataDecoder().decode(instruction.data)
  };
}
function getRequestSeatAuthorizedInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([["discriminator", web3_js.getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 105 })
  );
}
function getRequestSeatAuthorizedInstructionDataDecoder() {
  return web3_js.getStructDecoder([["discriminator", web3_js.getU8Decoder()]]);
}
function getRequestSeatAuthorizedInstructionDataCodec() {
  return web3_js.combineCodec(
    getRequestSeatAuthorizedInstructionDataEncoder(),
    getRequestSeatAuthorizedInstructionDataDecoder()
  );
}
function getRequestSeatAuthorizedInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getRequestSeatAuthorizedInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRequestSeatAuthorizedInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      payer: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getRequestSeatAuthorizedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSwapInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 0 })
  );
}
function getSwapInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getSwapInstructionDataCodec() {
  return web3_js.combineCodec(
    getSwapInstructionDataEncoder(),
    getSwapInstructionDataDecoder()
  );
}
function getSwapInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getSwapInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSwapInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getSwapInstructionDataDecoder().decode(instruction.data)
  };
}
function getSwapWithFreeFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 1 })
  );
}
function getSwapWithFreeFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getSwapWithFreeFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getSwapWithFreeFundsInstructionDataEncoder(),
    getSwapWithFreeFundsInstructionDataDecoder()
  );
}
function getSwapWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getSwapWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSwapWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount()
    },
    data: getSwapWithFreeFundsInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawFundsInstructionDataEncoder() {
  return web3_js.transformEncoder(
    web3_js.getStructEncoder([
      ["discriminator", web3_js.getU8Encoder()],
      ["quoteLotsToWithdraw", web3_js.getOptionEncoder(web3_js.getU64Encoder())],
      ["baseLotsToWithdraw", web3_js.getOptionEncoder(web3_js.getU64Encoder())]
    ]),
    (value) => ({ ...value, discriminator: 12 })
  );
}
function getWithdrawFundsInstructionDataDecoder() {
  return web3_js.getStructDecoder([
    ["discriminator", web3_js.getU8Decoder()],
    ["quoteLotsToWithdraw", web3_js.getOptionDecoder(web3_js.getU64Decoder())],
    ["baseLotsToWithdraw", web3_js.getOptionDecoder(web3_js.getU64Decoder())]
  ]);
}
function getWithdrawFundsInstructionDataCodec() {
  return web3_js.combineCodec(
    getWithdrawFundsInstructionDataEncoder(),
    getWithdrawFundsInstructionDataDecoder()
  );
}
function getWithdrawFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getWithdrawFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawFundsInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getWithdrawFundsInstructionDataDecoder().decode(instruction.data)
  };
}

// src/helpers/market.ts
var MIN_MARKET_SIZE_PARAMS = {
  bidsSize: 512n,
  asksSize: 512n,
  numSeats: 128n
};
var MIN_MARKET_SIZE = 84368n;
var MARKET_HEADER_SIZE = 576n;
var MarketState = class {
  address;
  data;
  constructor(address, data) {
    this.address = address;
    this.data = data;
  }
  // static load(address: Address, buffer: Buffer): Promise<MarketState> {
  //   const marketData = deserializeMarketData(buffer);
  //   return new MarketState(address, data.value);
  // }
};

// src/helpers/index.ts
async function getLogAuthority() {
  const programAddress = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [web3_js.getUtf8Encoder().encode("log")]
  });
}
async function findMintVaultPda(seeds) {
  const programAddress = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("vault"),
      web3_js.getAddressEncoder().encode(seeds.market),
      web3_js.getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findSeatPda(seeds) {
  const programAddress = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
  return await web3_js.getProgramDerivedAddress({
    programAddress,
    seeds: [
      web3_js.getUtf8Encoder().encode("seat"),
      web3_js.getAddressEncoder().encode(seeds.market),
      web3_js.getAddressEncoder().encode(seeds.trader)
    ]
  });
}

exports.FailedMultipleLimitOrderBehavior = FailedMultipleLimitOrderBehavior;
exports.MARKET_HEADER_SIZE = MARKET_HEADER_SIZE;
exports.MIN_MARKET_SIZE = MIN_MARKET_SIZE;
exports.MIN_MARKET_SIZE_PARAMS = MIN_MARKET_SIZE_PARAMS;
exports.MarketState = MarketState;
exports.MarketStatus = MarketStatus;
exports.PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR = PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR;
exports.PHOENIX_V1_ERROR__EVICTION_ERROR = PHOENIX_V1_ERROR__EVICTION_ERROR;
exports.PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER = PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER;
exports.PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT = PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT;
exports.PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT = PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT;
exports.PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT = PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT;
exports.PHOENIX_V1_ERROR__INVALID_BASE_VAULT = PHOENIX_V1_ERROR__INVALID_BASE_VAULT;
exports.PHOENIX_V1_ERROR__INVALID_LOT_SIZE = PHOENIX_V1_ERROR__INVALID_LOT_SIZE;
exports.PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY = PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY;
exports.PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS = PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS;
exports.PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER = PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER;
exports.PHOENIX_V1_ERROR__INVALID_MINT = PHOENIX_V1_ERROR__INVALID_MINT;
exports.PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT = PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT;
exports.PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT = PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT;
exports.PHOENIX_V1_ERROR__INVALID_SEAT_STATUS = PHOENIX_V1_ERROR__INVALID_SEAT_STATUS;
exports.PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION = PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION;
exports.PHOENIX_V1_ERROR__INVALID_TICK_SIZE = PHOENIX_V1_ERROR__INVALID_TICK_SIZE;
exports.PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED = PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED;
exports.PHOENIX_V1_ERROR__MARKET_UNINITIALIZED = PHOENIX_V1_ERROR__MARKET_UNINITIALIZED;
exports.PHOENIX_V1_ERROR__NEW_ORDER_ERROR = PHOENIX_V1_ERROR__NEW_ORDER_ERROR;
exports.PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER = PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER;
exports.PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR = PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR;
exports.PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR = PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR;
exports.PHOENIX_V1_ERROR__TOO_MANY_EVENTS = PHOENIX_V1_ERROR__TOO_MANY_EVENTS;
exports.PHOENIX_V1_ERROR__TRADER_NOT_FOUND = PHOENIX_V1_ERROR__TRADER_NOT_FOUND;
exports.PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR = PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR;
exports.PHOENIX_V1_PROGRAM_ADDRESS = PHOENIX_V1_PROGRAM_ADDRESS;
exports.PhoenixV1Instruction = PhoenixV1Instruction;
exports.SeatApprovalStatus = SeatApprovalStatus;
exports.SelfTradeBehavior = SelfTradeBehavior2;
exports.Side = Side4;
exports.findMintVaultPda = findMintVaultPda;
exports.findSeatPda = findSeatPda;
exports.getAuditLogHeaderCodec = getAuditLogHeaderCodec;
exports.getAuditLogHeaderDecoder = getAuditLogHeaderDecoder;
exports.getAuditLogHeaderEncoder = getAuditLogHeaderEncoder;
exports.getCancelAllOrdersInstruction = getCancelAllOrdersInstruction;
exports.getCancelAllOrdersInstructionDataCodec = getCancelAllOrdersInstructionDataCodec;
exports.getCancelAllOrdersInstructionDataDecoder = getCancelAllOrdersInstructionDataDecoder;
exports.getCancelAllOrdersInstructionDataEncoder = getCancelAllOrdersInstructionDataEncoder;
exports.getCancelAllOrdersWithFreeFundsInstruction = getCancelAllOrdersWithFreeFundsInstruction;
exports.getCancelAllOrdersWithFreeFundsInstructionDataCodec = getCancelAllOrdersWithFreeFundsInstructionDataCodec;
exports.getCancelAllOrdersWithFreeFundsInstructionDataDecoder = getCancelAllOrdersWithFreeFundsInstructionDataDecoder;
exports.getCancelAllOrdersWithFreeFundsInstructionDataEncoder = getCancelAllOrdersWithFreeFundsInstructionDataEncoder;
exports.getCancelMultipleOrdersByIdInstruction = getCancelMultipleOrdersByIdInstruction;
exports.getCancelMultipleOrdersByIdInstructionDataCodec = getCancelMultipleOrdersByIdInstructionDataCodec;
exports.getCancelMultipleOrdersByIdInstructionDataDecoder = getCancelMultipleOrdersByIdInstructionDataDecoder;
exports.getCancelMultipleOrdersByIdInstructionDataEncoder = getCancelMultipleOrdersByIdInstructionDataEncoder;
exports.getCancelMultipleOrdersByIdParamsCodec = getCancelMultipleOrdersByIdParamsCodec;
exports.getCancelMultipleOrdersByIdParamsDecoder = getCancelMultipleOrdersByIdParamsDecoder;
exports.getCancelMultipleOrdersByIdParamsEncoder = getCancelMultipleOrdersByIdParamsEncoder;
exports.getCancelMultipleOrdersByIdWithFreeFundsInstruction = getCancelMultipleOrdersByIdWithFreeFundsInstruction;
exports.getCancelMultipleOrdersByIdWithFreeFundsInstructionDataCodec = getCancelMultipleOrdersByIdWithFreeFundsInstructionDataCodec;
exports.getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder = getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder;
exports.getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder = getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder;
exports.getCancelOrderParamsCodec = getCancelOrderParamsCodec;
exports.getCancelOrderParamsDecoder = getCancelOrderParamsDecoder;
exports.getCancelOrderParamsEncoder = getCancelOrderParamsEncoder;
exports.getCancelUpToInstruction = getCancelUpToInstruction;
exports.getCancelUpToInstructionDataCodec = getCancelUpToInstructionDataCodec;
exports.getCancelUpToInstructionDataDecoder = getCancelUpToInstructionDataDecoder;
exports.getCancelUpToInstructionDataEncoder = getCancelUpToInstructionDataEncoder;
exports.getCancelUpToParamsCodec = getCancelUpToParamsCodec;
exports.getCancelUpToParamsDecoder = getCancelUpToParamsDecoder;
exports.getCancelUpToParamsEncoder = getCancelUpToParamsEncoder;
exports.getCancelUpToWithFreeFundsInstruction = getCancelUpToWithFreeFundsInstruction;
exports.getCancelUpToWithFreeFundsInstructionDataCodec = getCancelUpToWithFreeFundsInstructionDataCodec;
exports.getCancelUpToWithFreeFundsInstructionDataDecoder = getCancelUpToWithFreeFundsInstructionDataDecoder;
exports.getCancelUpToWithFreeFundsInstructionDataEncoder = getCancelUpToWithFreeFundsInstructionDataEncoder;
exports.getChangeFeeRecipientInstruction = getChangeFeeRecipientInstruction;
exports.getChangeFeeRecipientInstructionDataCodec = getChangeFeeRecipientInstructionDataCodec;
exports.getChangeFeeRecipientInstructionDataDecoder = getChangeFeeRecipientInstructionDataDecoder;
exports.getChangeFeeRecipientInstructionDataEncoder = getChangeFeeRecipientInstructionDataEncoder;
exports.getChangeMarketStatusInstruction = getChangeMarketStatusInstruction;
exports.getChangeMarketStatusInstructionDataCodec = getChangeMarketStatusInstructionDataCodec;
exports.getChangeMarketStatusInstructionDataDecoder = getChangeMarketStatusInstructionDataDecoder;
exports.getChangeMarketStatusInstructionDataEncoder = getChangeMarketStatusInstructionDataEncoder;
exports.getChangeSeatStatusInstruction = getChangeSeatStatusInstruction;
exports.getChangeSeatStatusInstructionDataCodec = getChangeSeatStatusInstructionDataCodec;
exports.getChangeSeatStatusInstructionDataDecoder = getChangeSeatStatusInstructionDataDecoder;
exports.getChangeSeatStatusInstructionDataEncoder = getChangeSeatStatusInstructionDataEncoder;
exports.getClaimAuthorityInstruction = getClaimAuthorityInstruction;
exports.getClaimAuthorityInstructionDataCodec = getClaimAuthorityInstructionDataCodec;
exports.getClaimAuthorityInstructionDataDecoder = getClaimAuthorityInstructionDataDecoder;
exports.getClaimAuthorityInstructionDataEncoder = getClaimAuthorityInstructionDataEncoder;
exports.getCollectFeesInstruction = getCollectFeesInstruction;
exports.getCollectFeesInstructionDataCodec = getCollectFeesInstructionDataCodec;
exports.getCollectFeesInstructionDataDecoder = getCollectFeesInstructionDataDecoder;
exports.getCollectFeesInstructionDataEncoder = getCollectFeesInstructionDataEncoder;
exports.getCondensedOrderCodec = getCondensedOrderCodec;
exports.getCondensedOrderDecoder = getCondensedOrderDecoder;
exports.getCondensedOrderEncoder = getCondensedOrderEncoder;
exports.getDepositFundsInstruction = getDepositFundsInstruction;
exports.getDepositFundsInstructionDataCodec = getDepositFundsInstructionDataCodec;
exports.getDepositFundsInstructionDataDecoder = getDepositFundsInstructionDataDecoder;
exports.getDepositFundsInstructionDataEncoder = getDepositFundsInstructionDataEncoder;
exports.getEvictEventCodec = getEvictEventCodec;
exports.getEvictEventDecoder = getEvictEventDecoder;
exports.getEvictEventEncoder = getEvictEventEncoder;
exports.getEvictSeatInstruction = getEvictSeatInstruction;
exports.getEvictSeatInstructionDataCodec = getEvictSeatInstructionDataCodec;
exports.getEvictSeatInstructionDataDecoder = getEvictSeatInstructionDataDecoder;
exports.getEvictSeatInstructionDataEncoder = getEvictSeatInstructionDataEncoder;
exports.getExpiredOrderEventCodec = getExpiredOrderEventCodec;
exports.getExpiredOrderEventDecoder = getExpiredOrderEventDecoder;
exports.getExpiredOrderEventEncoder = getExpiredOrderEventEncoder;
exports.getFIFOOrderIdCodec = getFIFOOrderIdCodec;
exports.getFIFOOrderIdDecoder = getFIFOOrderIdDecoder;
exports.getFIFOOrderIdEncoder = getFIFOOrderIdEncoder;
exports.getFailedMultipleLimitOrderBehaviorCodec = getFailedMultipleLimitOrderBehaviorCodec;
exports.getFailedMultipleLimitOrderBehaviorDecoder = getFailedMultipleLimitOrderBehaviorDecoder;
exports.getFailedMultipleLimitOrderBehaviorEncoder = getFailedMultipleLimitOrderBehaviorEncoder;
exports.getFeeEventCodec = getFeeEventCodec;
exports.getFeeEventDecoder = getFeeEventDecoder;
exports.getFeeEventEncoder = getFeeEventEncoder;
exports.getFillEventCodec = getFillEventCodec;
exports.getFillEventDecoder = getFillEventDecoder;
exports.getFillEventEncoder = getFillEventEncoder;
exports.getFillSummaryEventCodec = getFillSummaryEventCodec;
exports.getFillSummaryEventDecoder = getFillSummaryEventDecoder;
exports.getFillSummaryEventEncoder = getFillSummaryEventEncoder;
exports.getForceCancelOrdersInstruction = getForceCancelOrdersInstruction;
exports.getForceCancelOrdersInstructionDataCodec = getForceCancelOrdersInstructionDataCodec;
exports.getForceCancelOrdersInstructionDataDecoder = getForceCancelOrdersInstructionDataDecoder;
exports.getForceCancelOrdersInstructionDataEncoder = getForceCancelOrdersInstructionDataEncoder;
exports.getInitializeMarketInstruction = getInitializeMarketInstruction;
exports.getInitializeMarketInstructionDataCodec = getInitializeMarketInstructionDataCodec;
exports.getInitializeMarketInstructionDataDecoder = getInitializeMarketInstructionDataDecoder;
exports.getInitializeMarketInstructionDataEncoder = getInitializeMarketInstructionDataEncoder;
exports.getLogAuthority = getLogAuthority;
exports.getLogInstruction = getLogInstruction;
exports.getLogInstructionDataCodec = getLogInstructionDataCodec;
exports.getLogInstructionDataDecoder = getLogInstructionDataDecoder;
exports.getLogInstructionDataEncoder = getLogInstructionDataEncoder;
exports.getMarketHeaderCodec = getMarketHeaderCodec;
exports.getMarketHeaderDecoder = getMarketHeaderDecoder;
exports.getMarketHeaderEncoder = getMarketHeaderEncoder;
exports.getMarketSizeParamsCodec = getMarketSizeParamsCodec;
exports.getMarketSizeParamsDecoder = getMarketSizeParamsDecoder;
exports.getMarketSizeParamsEncoder = getMarketSizeParamsEncoder;
exports.getMarketStatusCodec = getMarketStatusCodec;
exports.getMarketStatusDecoder = getMarketStatusDecoder;
exports.getMarketStatusEncoder = getMarketStatusEncoder;
exports.getMultipleOrderPacketCodec = getMultipleOrderPacketCodec;
exports.getMultipleOrderPacketDecoder = getMultipleOrderPacketDecoder;
exports.getMultipleOrderPacketEncoder = getMultipleOrderPacketEncoder;
exports.getNameSuccessorInstruction = getNameSuccessorInstruction;
exports.getNameSuccessorInstructionDataCodec = getNameSuccessorInstructionDataCodec;
exports.getNameSuccessorInstructionDataDecoder = getNameSuccessorInstructionDataDecoder;
exports.getNameSuccessorInstructionDataEncoder = getNameSuccessorInstructionDataEncoder;
exports.getOrderPacketCodec = getOrderPacketCodec;
exports.getOrderPacketDecoder = getOrderPacketDecoder;
exports.getOrderPacketEncoder = getOrderPacketEncoder;
exports.getPhoenixMarketEventCodec = getPhoenixMarketEventCodec;
exports.getPhoenixMarketEventDecoder = getPhoenixMarketEventDecoder;
exports.getPhoenixMarketEventEncoder = getPhoenixMarketEventEncoder;
exports.getPhoenixV1ErrorMessage = getPhoenixV1ErrorMessage;
exports.getPlaceEventCodec = getPlaceEventCodec;
exports.getPlaceEventDecoder = getPlaceEventDecoder;
exports.getPlaceEventEncoder = getPlaceEventEncoder;
exports.getPlaceLimitOrderInstruction = getPlaceLimitOrderInstruction;
exports.getPlaceLimitOrderInstructionDataCodec = getPlaceLimitOrderInstructionDataCodec;
exports.getPlaceLimitOrderInstructionDataDecoder = getPlaceLimitOrderInstructionDataDecoder;
exports.getPlaceLimitOrderInstructionDataEncoder = getPlaceLimitOrderInstructionDataEncoder;
exports.getPlaceLimitOrderWithFreeFundsInstruction = getPlaceLimitOrderWithFreeFundsInstruction;
exports.getPlaceLimitOrderWithFreeFundsInstructionDataCodec = getPlaceLimitOrderWithFreeFundsInstructionDataCodec;
exports.getPlaceLimitOrderWithFreeFundsInstructionDataDecoder = getPlaceLimitOrderWithFreeFundsInstructionDataDecoder;
exports.getPlaceLimitOrderWithFreeFundsInstructionDataEncoder = getPlaceLimitOrderWithFreeFundsInstructionDataEncoder;
exports.getPlaceMultiplePostOnlyOrdersInstruction = getPlaceMultiplePostOnlyOrdersInstruction;
exports.getPlaceMultiplePostOnlyOrdersInstructionDataCodec = getPlaceMultiplePostOnlyOrdersInstructionDataCodec;
exports.getPlaceMultiplePostOnlyOrdersInstructionDataDecoder = getPlaceMultiplePostOnlyOrdersInstructionDataDecoder;
exports.getPlaceMultiplePostOnlyOrdersInstructionDataEncoder = getPlaceMultiplePostOnlyOrdersInstructionDataEncoder;
exports.getPlaceMultiplePostOnlyOrdersWithFreeFundsInstruction = getPlaceMultiplePostOnlyOrdersWithFreeFundsInstruction;
exports.getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataCodec = getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataCodec;
exports.getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder = getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder;
exports.getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder = getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder;
exports.getReduceEventCodec = getReduceEventCodec;
exports.getReduceEventDecoder = getReduceEventDecoder;
exports.getReduceEventEncoder = getReduceEventEncoder;
exports.getReduceOrderInstruction = getReduceOrderInstruction;
exports.getReduceOrderInstructionDataCodec = getReduceOrderInstructionDataCodec;
exports.getReduceOrderInstructionDataDecoder = getReduceOrderInstructionDataDecoder;
exports.getReduceOrderInstructionDataEncoder = getReduceOrderInstructionDataEncoder;
exports.getReduceOrderParamsCodec = getReduceOrderParamsCodec;
exports.getReduceOrderParamsDecoder = getReduceOrderParamsDecoder;
exports.getReduceOrderParamsEncoder = getReduceOrderParamsEncoder;
exports.getReduceOrderWithFreeFundsInstruction = getReduceOrderWithFreeFundsInstruction;
exports.getReduceOrderWithFreeFundsInstructionDataCodec = getReduceOrderWithFreeFundsInstructionDataCodec;
exports.getReduceOrderWithFreeFundsInstructionDataDecoder = getReduceOrderWithFreeFundsInstructionDataDecoder;
exports.getReduceOrderWithFreeFundsInstructionDataEncoder = getReduceOrderWithFreeFundsInstructionDataEncoder;
exports.getRequestSeatAuthorizedInstruction = getRequestSeatAuthorizedInstruction;
exports.getRequestSeatAuthorizedInstructionDataCodec = getRequestSeatAuthorizedInstructionDataCodec;
exports.getRequestSeatAuthorizedInstructionDataDecoder = getRequestSeatAuthorizedInstructionDataDecoder;
exports.getRequestSeatAuthorizedInstructionDataEncoder = getRequestSeatAuthorizedInstructionDataEncoder;
exports.getRequestSeatInstruction = getRequestSeatInstruction;
exports.getRequestSeatInstructionDataCodec = getRequestSeatInstructionDataCodec;
exports.getRequestSeatInstructionDataDecoder = getRequestSeatInstructionDataDecoder;
exports.getRequestSeatInstructionDataEncoder = getRequestSeatInstructionDataEncoder;
exports.getSeatApprovalStatusCodec = getSeatApprovalStatusCodec;
exports.getSeatApprovalStatusDecoder = getSeatApprovalStatusDecoder;
exports.getSeatApprovalStatusEncoder = getSeatApprovalStatusEncoder;
exports.getSeatCodec = getSeatCodec;
exports.getSeatDecoder = getSeatDecoder;
exports.getSeatEncoder = getSeatEncoder;
exports.getSelfTradeBehaviorCodec = getSelfTradeBehaviorCodec;
exports.getSelfTradeBehaviorDecoder = getSelfTradeBehaviorDecoder;
exports.getSelfTradeBehaviorEncoder = getSelfTradeBehaviorEncoder;
exports.getSideCodec = getSideCodec;
exports.getSideDecoder = getSideDecoder;
exports.getSideEncoder = getSideEncoder;
exports.getSwapInstruction = getSwapInstruction;
exports.getSwapInstructionDataCodec = getSwapInstructionDataCodec;
exports.getSwapInstructionDataDecoder = getSwapInstructionDataDecoder;
exports.getSwapInstructionDataEncoder = getSwapInstructionDataEncoder;
exports.getSwapWithFreeFundsInstruction = getSwapWithFreeFundsInstruction;
exports.getSwapWithFreeFundsInstructionDataCodec = getSwapWithFreeFundsInstructionDataCodec;
exports.getSwapWithFreeFundsInstructionDataDecoder = getSwapWithFreeFundsInstructionDataDecoder;
exports.getSwapWithFreeFundsInstructionDataEncoder = getSwapWithFreeFundsInstructionDataEncoder;
exports.getTimeInForceEventCodec = getTimeInForceEventCodec;
exports.getTimeInForceEventDecoder = getTimeInForceEventDecoder;
exports.getTimeInForceEventEncoder = getTimeInForceEventEncoder;
exports.getTokenParamsCodec = getTokenParamsCodec;
exports.getTokenParamsDecoder = getTokenParamsDecoder;
exports.getTokenParamsEncoder = getTokenParamsEncoder;
exports.getWithdrawFundsInstruction = getWithdrawFundsInstruction;
exports.getWithdrawFundsInstructionDataCodec = getWithdrawFundsInstructionDataCodec;
exports.getWithdrawFundsInstructionDataDecoder = getWithdrawFundsInstructionDataDecoder;
exports.getWithdrawFundsInstructionDataEncoder = getWithdrawFundsInstructionDataEncoder;
exports.identifyPhoenixV1Instruction = identifyPhoenixV1Instruction;
exports.isOrderPacket = isOrderPacket;
exports.isPhoenixMarketEvent = isPhoenixMarketEvent;
exports.orderPacket = orderPacket;
exports.parseCancelAllOrdersInstruction = parseCancelAllOrdersInstruction;
exports.parseCancelAllOrdersWithFreeFundsInstruction = parseCancelAllOrdersWithFreeFundsInstruction;
exports.parseCancelMultipleOrdersByIdInstruction = parseCancelMultipleOrdersByIdInstruction;
exports.parseCancelMultipleOrdersByIdWithFreeFundsInstruction = parseCancelMultipleOrdersByIdWithFreeFundsInstruction;
exports.parseCancelUpToInstruction = parseCancelUpToInstruction;
exports.parseCancelUpToWithFreeFundsInstruction = parseCancelUpToWithFreeFundsInstruction;
exports.parseChangeFeeRecipientInstruction = parseChangeFeeRecipientInstruction;
exports.parseChangeMarketStatusInstruction = parseChangeMarketStatusInstruction;
exports.parseChangeSeatStatusInstruction = parseChangeSeatStatusInstruction;
exports.parseClaimAuthorityInstruction = parseClaimAuthorityInstruction;
exports.parseCollectFeesInstruction = parseCollectFeesInstruction;
exports.parseDepositFundsInstruction = parseDepositFundsInstruction;
exports.parseEvictSeatInstruction = parseEvictSeatInstruction;
exports.parseForceCancelOrdersInstruction = parseForceCancelOrdersInstruction;
exports.parseInitializeMarketInstruction = parseInitializeMarketInstruction;
exports.parseLogInstruction = parseLogInstruction;
exports.parseNameSuccessorInstruction = parseNameSuccessorInstruction;
exports.parsePlaceLimitOrderInstruction = parsePlaceLimitOrderInstruction;
exports.parsePlaceLimitOrderWithFreeFundsInstruction = parsePlaceLimitOrderWithFreeFundsInstruction;
exports.parsePlaceMultiplePostOnlyOrdersInstruction = parsePlaceMultiplePostOnlyOrdersInstruction;
exports.parsePlaceMultiplePostOnlyOrdersWithFreeFundsInstruction = parsePlaceMultiplePostOnlyOrdersWithFreeFundsInstruction;
exports.parseReduceOrderInstruction = parseReduceOrderInstruction;
exports.parseReduceOrderWithFreeFundsInstruction = parseReduceOrderWithFreeFundsInstruction;
exports.parseRequestSeatAuthorizedInstruction = parseRequestSeatAuthorizedInstruction;
exports.parseRequestSeatInstruction = parseRequestSeatInstruction;
exports.parseSwapInstruction = parseSwapInstruction;
exports.parseSwapWithFreeFundsInstruction = parseSwapWithFreeFundsInstruction;
exports.parseWithdrawFundsInstruction = parseWithdrawFundsInstruction;
exports.phoenixMarketEvent = phoenixMarketEvent;
//# sourceMappingURL=index.js.map
//# sourceMappingURL=index.js.map