import { containsBytes, getU8Encoder, transformEncoder, getStructEncoder, getStructDecoder, getU8Decoder, combineCodec, getU64Encoder, getI64Encoder, getAddressEncoder, getU16Encoder, getU64Decoder, getI64Decoder, getAddressDecoder, getU16Decoder, getArrayEncoder, getArrayDecoder, getOptionEncoder, getU32Encoder, getOptionDecoder, getU32Decoder, getEnumEncoder, getEnumDecoder, getU128Encoder, getU128Decoder, getDiscriminatedUnionEncoder, getBooleanEncoder, getDiscriminatedUnionDecoder, getBooleanDecoder, getUnitEncoder, getTupleEncoder, getUnitDecoder, getTupleDecoder, getProgramDerivedAddress, getUtf8Encoder, AccountRole, upgradeRoleToSigner, isTransactionSigner as isTransactionSigner$1 } from '@solana/web3.js';

// env-shim.ts
var __DEV__ = /* @__PURE__ */ (() => process["env"].NODE_ENV === "development")();

// src/generated/errors/phoenixV1.ts
var PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS = 0;
var PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY = 1;
var PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT = 2;
var PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED = 3;
var PHOENIX_V1_ERROR__MARKET_UNINITIALIZED = 4;
var PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION = 5;
var PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER = 6;
var PHOENIX_V1_ERROR__INVALID_LOT_SIZE = 7;
var PHOENIX_V1_ERROR__INVALID_TICK_SIZE = 8;
var PHOENIX_V1_ERROR__INVALID_MINT = 9;
var PHOENIX_V1_ERROR__INVALID_BASE_VAULT = 10;
var PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT = 11;
var PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT = 12;
var PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT = 13;
var PHOENIX_V1_ERROR__TOO_MANY_EVENTS = 14;
var PHOENIX_V1_ERROR__NEW_ORDER_ERROR = 15;
var PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR = 16;
var PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR = 17;
var PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR = 18;
var PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR = 19;
var PHOENIX_V1_ERROR__TRADER_NOT_FOUND = 20;
var PHOENIX_V1_ERROR__INVALID_SEAT_STATUS = 21;
var PHOENIX_V1_ERROR__EVICTION_ERROR = 22;
var PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER = 23;
var PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT = 24;
var PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER = 25;
var phoenixV1ErrorMessages;
if (__DEV__) {
  phoenixV1ErrorMessages = {
    [PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR]: `Cancel multiple orders error`,
    [PHOENIX_V1_ERROR__EVICTION_ERROR]: `Failed to evict trader`,
    [PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER]: `Failed to flush buffer`,
    [PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT]: `Market deserialization error`,
    [PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT]: `Failed to serialize event`,
    [PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT]: `Invalid base account error`,
    [PHOENIX_V1_ERROR__INVALID_BASE_VAULT]: `Invalid base vault error`,
    [PHOENIX_V1_ERROR__INVALID_LOT_SIZE]: `Invalid lot size error`,
    [PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY]: `Invalid market authority error`,
    [PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS]: `Invalid market parameters error`,
    [PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER]: `Invalid market signer error`,
    [PHOENIX_V1_ERROR__INVALID_MINT]: `Invalid mint error`,
    [PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT]: `Invalid quote account error`,
    [PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT]: `Invalid quote vault error`,
    [PHOENIX_V1_ERROR__INVALID_SEAT_STATUS]: `Invalid seat status`,
    [PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION]: `Invalid state transition error`,
    [PHOENIX_V1_ERROR__INVALID_TICK_SIZE]: `Invalid tick size error`,
    [PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED]: `Market already initialized error`,
    [PHOENIX_V1_ERROR__MARKET_UNINITIALIZED]: `Market is not initialized error`,
    [PHOENIX_V1_ERROR__NEW_ORDER_ERROR]: `New order error`,
    [PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER]: `Non empty scratch buffer`,
    [PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR]: `Reduce order error`,
    [PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR]: `Remove empty orders error`,
    [PHOENIX_V1_ERROR__TOO_MANY_EVENTS]: `Too many events error`,
    [PHOENIX_V1_ERROR__TRADER_NOT_FOUND]: `Trader not found error`,
    [PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR]: `Withdraw funds error`
  };
}
function getPhoenixV1ErrorMessage(code) {
  if (__DEV__) {
    return phoenixV1ErrorMessages[code];
  }
  return "Error message not available in production bundles. Compile with `__DEV__` set to true to see more information.";
}
var PHOENIX_V1_PROGRAM_ADDRESS = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
var PhoenixV1Instruction = /* @__PURE__ */ ((PhoenixV1Instruction2) => {
  PhoenixV1Instruction2[PhoenixV1Instruction2["Swap"] = 0] = "Swap";
  PhoenixV1Instruction2[PhoenixV1Instruction2["SwapWithFreeFunds"] = 1] = "SwapWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceLimitOrder"] = 2] = "PlaceLimitOrder";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceLimitOrderWithFreeFunds"] = 3] = "PlaceLimitOrderWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ReduceOrder"] = 4] = "ReduceOrder";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ReduceOrderWithFreeFunds"] = 5] = "ReduceOrderWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelAllOrders"] = 6] = "CancelAllOrders";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelAllOrdersWithFreeFunds"] = 7] = "CancelAllOrdersWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelUpTo"] = 8] = "CancelUpTo";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelUpToWithFreeFunds"] = 9] = "CancelUpToWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelMultipleOrdersById"] = 10] = "CancelMultipleOrdersById";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CancelMultipleOrdersByIdWithFreeFunds"] = 11] = "CancelMultipleOrdersByIdWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["WithdrawFunds"] = 12] = "WithdrawFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["DepositFunds"] = 13] = "DepositFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["RequestSeat"] = 14] = "RequestSeat";
  PhoenixV1Instruction2[PhoenixV1Instruction2["Log"] = 15] = "Log";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceMultiplePostOnlyOrders"] = 16] = "PlaceMultiplePostOnlyOrders";
  PhoenixV1Instruction2[PhoenixV1Instruction2["PlaceMultiplePostOnlyOrdersWithFreeFunds"] = 17] = "PlaceMultiplePostOnlyOrdersWithFreeFunds";
  PhoenixV1Instruction2[PhoenixV1Instruction2["InitializeMarket"] = 18] = "InitializeMarket";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ClaimAuthority"] = 19] = "ClaimAuthority";
  PhoenixV1Instruction2[PhoenixV1Instruction2["NameSuccessor"] = 20] = "NameSuccessor";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ChangeMarketStatus"] = 21] = "ChangeMarketStatus";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ChangeSeatStatus"] = 22] = "ChangeSeatStatus";
  PhoenixV1Instruction2[PhoenixV1Instruction2["RequestSeatAuthorized"] = 23] = "RequestSeatAuthorized";
  PhoenixV1Instruction2[PhoenixV1Instruction2["EvictSeat"] = 24] = "EvictSeat";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ForceCancelOrders"] = 25] = "ForceCancelOrders";
  PhoenixV1Instruction2[PhoenixV1Instruction2["CollectFees"] = 26] = "CollectFees";
  PhoenixV1Instruction2[PhoenixV1Instruction2["ChangeFeeRecipient"] = 27] = "ChangeFeeRecipient";
  return PhoenixV1Instruction2;
})(PhoenixV1Instruction || {});
function identifyPhoenixV1Instruction(instruction) {
  const data = instruction instanceof Uint8Array ? instruction : instruction.data;
  if (containsBytes(data, getU8Encoder().encode(0), 0)) {
    return 0 /* Swap */;
  }
  if (containsBytes(data, getU8Encoder().encode(1), 0)) {
    return 1 /* SwapWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(2), 0)) {
    return 2 /* PlaceLimitOrder */;
  }
  if (containsBytes(data, getU8Encoder().encode(3), 0)) {
    return 3 /* PlaceLimitOrderWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(4), 0)) {
    return 4 /* ReduceOrder */;
  }
  if (containsBytes(data, getU8Encoder().encode(5), 0)) {
    return 5 /* ReduceOrderWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(6), 0)) {
    return 6 /* CancelAllOrders */;
  }
  if (containsBytes(data, getU8Encoder().encode(7), 0)) {
    return 7 /* CancelAllOrdersWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(8), 0)) {
    return 8 /* CancelUpTo */;
  }
  if (containsBytes(data, getU8Encoder().encode(9), 0)) {
    return 9 /* CancelUpToWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(10), 0)) {
    return 10 /* CancelMultipleOrdersById */;
  }
  if (containsBytes(data, getU8Encoder().encode(11), 0)) {
    return 11 /* CancelMultipleOrdersByIdWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(12), 0)) {
    return 12 /* WithdrawFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(13), 0)) {
    return 13 /* DepositFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(14), 0)) {
    return 14 /* RequestSeat */;
  }
  if (containsBytes(data, getU8Encoder().encode(15), 0)) {
    return 15 /* Log */;
  }
  if (containsBytes(data, getU8Encoder().encode(16), 0)) {
    return 16 /* PlaceMultiplePostOnlyOrders */;
  }
  if (containsBytes(data, getU8Encoder().encode(17), 0)) {
    return 17 /* PlaceMultiplePostOnlyOrdersWithFreeFunds */;
  }
  if (containsBytes(data, getU8Encoder().encode(100), 0)) {
    return 18 /* InitializeMarket */;
  }
  if (containsBytes(data, getU8Encoder().encode(101), 0)) {
    return 19 /* ClaimAuthority */;
  }
  if (containsBytes(data, getU8Encoder().encode(102), 0)) {
    return 20 /* NameSuccessor */;
  }
  if (containsBytes(data, getU8Encoder().encode(103), 0)) {
    return 21 /* ChangeMarketStatus */;
  }
  if (containsBytes(data, getU8Encoder().encode(104), 0)) {
    return 22 /* ChangeSeatStatus */;
  }
  if (containsBytes(data, getU8Encoder().encode(105), 0)) {
    return 23 /* RequestSeatAuthorized */;
  }
  if (containsBytes(data, getU8Encoder().encode(106), 0)) {
    return 24 /* EvictSeat */;
  }
  if (containsBytes(data, getU8Encoder().encode(107), 0)) {
    return 25 /* ForceCancelOrders */;
  }
  if (containsBytes(data, getU8Encoder().encode(108), 0)) {
    return 26 /* CollectFees */;
  }
  if (containsBytes(data, getU8Encoder().encode(109), 0)) {
    return 27 /* ChangeFeeRecipient */;
  }
  throw new Error(
    "The provided instruction could not be identified as a phoenixV1 instruction."
  );
}
function expectAddress(value) {
  if (!value) {
    throw new Error("Expected a Address.");
  }
  if (typeof value === "object" && "address" in value) {
    return value.address;
  }
  if (Array.isArray(value)) {
    return value[0];
  }
  return value;
}
function getAccountMetaFactory(programAddress, optionalAccountStrategy) {
  return (account) => {
    if (!account.value) {
      return Object.freeze({
        address: programAddress,
        role: AccountRole.READONLY
      });
    }
    const writableRole = account.isWritable ? AccountRole.WRITABLE : AccountRole.READONLY;
    return Object.freeze({
      address: expectAddress(account.value),
      role: isTransactionSigner(account.value) ? upgradeRoleToSigner(writableRole) : writableRole,
      ...isTransactionSigner(account.value) ? { signer: account.value } : {}
    });
  };
}
function isTransactionSigner(value) {
  return !!value && typeof value === "object" && "address" in value && isTransactionSigner$1(value);
}

// src/generated/instructions/cancelAllOrders.ts
function getCancelAllOrdersInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 6 })
  );
}
function getCancelAllOrdersInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getCancelAllOrdersInstructionDataCodec() {
  return combineCodec(
    getCancelAllOrdersInstructionDataEncoder(),
    getCancelAllOrdersInstructionDataDecoder()
  );
}
function getCancelAllOrdersInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCancelAllOrdersInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCancelAllOrdersInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCancelAllOrdersInstructionDataDecoder().decode(instruction.data)
  };
}
function getCancelAllOrdersWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 7 })
  );
}
function getCancelAllOrdersWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getCancelAllOrdersWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getCancelAllOrdersWithFreeFundsInstructionDataEncoder(),
    getCancelAllOrdersWithFreeFundsInstructionDataDecoder()
  );
}
function getCancelAllOrdersWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getCancelAllOrdersWithFreeFundsInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCancelAllOrdersWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getCancelAllOrdersWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getAuditLogHeaderEncoder() {
  return getStructEncoder([
    ["instruction", getU8Encoder()],
    ["sequenceNumber", getU64Encoder()],
    ["timestamp", getI64Encoder()],
    ["slot", getU64Encoder()],
    ["market", getAddressEncoder()],
    ["signer", getAddressEncoder()],
    ["totalEvents", getU16Encoder()]
  ]);
}
function getAuditLogHeaderDecoder() {
  return getStructDecoder([
    ["instruction", getU8Decoder()],
    ["sequenceNumber", getU64Decoder()],
    ["timestamp", getI64Decoder()],
    ["slot", getU64Decoder()],
    ["market", getAddressDecoder()],
    ["signer", getAddressDecoder()],
    ["totalEvents", getU16Decoder()]
  ]);
}
function getAuditLogHeaderCodec() {
  return combineCodec(getAuditLogHeaderEncoder(), getAuditLogHeaderDecoder());
}
function getCancelMultipleOrdersByIdParamsEncoder() {
  return getStructEncoder([
    ["orders", getArrayEncoder(getCancelOrderParamsEncoder())]
  ]);
}
function getCancelMultipleOrdersByIdParamsDecoder() {
  return getStructDecoder([
    ["orders", getArrayDecoder(getCancelOrderParamsDecoder())]
  ]);
}
function getCancelMultipleOrdersByIdParamsCodec() {
  return combineCodec(
    getCancelMultipleOrdersByIdParamsEncoder(),
    getCancelMultipleOrdersByIdParamsDecoder()
  );
}
function getCancelOrderParamsEncoder() {
  return getStructEncoder([
    ["side", getSideEncoder()],
    ["priceInTicks", getU64Encoder()],
    ["orderSequenceNumber", getU64Encoder()]
  ]);
}
function getCancelOrderParamsDecoder() {
  return getStructDecoder([
    ["side", getSideDecoder()],
    ["priceInTicks", getU64Decoder()],
    ["orderSequenceNumber", getU64Decoder()]
  ]);
}
function getCancelOrderParamsCodec() {
  return combineCodec(
    getCancelOrderParamsEncoder(),
    getCancelOrderParamsDecoder()
  );
}
function getCancelUpToParamsEncoder() {
  return getStructEncoder([
    ["side", getSideEncoder()],
    ["tickLimit", getOptionEncoder(getU64Encoder())],
    ["numOrdersToSearch", getOptionEncoder(getU32Encoder())],
    ["numOrdersToCancel", getOptionEncoder(getU32Encoder())]
  ]);
}
function getCancelUpToParamsDecoder() {
  return getStructDecoder([
    ["side", getSideDecoder()],
    ["tickLimit", getOptionDecoder(getU64Decoder())],
    ["numOrdersToSearch", getOptionDecoder(getU32Decoder())],
    ["numOrdersToCancel", getOptionDecoder(getU32Decoder())]
  ]);
}
function getCancelUpToParamsCodec() {
  return combineCodec(
    getCancelUpToParamsEncoder(),
    getCancelUpToParamsDecoder()
  );
}
function getCondensedOrderEncoder() {
  return getStructEncoder([
    ["priceInTicks", getU64Encoder()],
    ["sizeInBaseLots", getU64Encoder()],
    ["lastValidSlot", getOptionEncoder(getU64Encoder())],
    ["lastValidUnixTimestampInSeconds", getOptionEncoder(getU64Encoder())]
  ]);
}
function getCondensedOrderDecoder() {
  return getStructDecoder([
    ["priceInTicks", getU64Decoder()],
    ["sizeInBaseLots", getU64Decoder()],
    ["lastValidSlot", getOptionDecoder(getU64Decoder())],
    ["lastValidUnixTimestampInSeconds", getOptionDecoder(getU64Decoder())]
  ]);
}
function getCondensedOrderCodec() {
  return combineCodec(getCondensedOrderEncoder(), getCondensedOrderDecoder());
}
function getEvictEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["makerId", getAddressEncoder()],
    ["orderSequenceNumber", getU64Encoder()],
    ["priceInTicks", getU64Encoder()],
    ["baseLotsEvicted", getU64Encoder()]
  ]);
}
function getEvictEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["makerId", getAddressDecoder()],
    ["orderSequenceNumber", getU64Decoder()],
    ["priceInTicks", getU64Decoder()],
    ["baseLotsEvicted", getU64Decoder()]
  ]);
}
function getEvictEventCodec() {
  return combineCodec(getEvictEventEncoder(), getEvictEventDecoder());
}
function getExpiredOrderEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["makerId", getAddressEncoder()],
    ["orderSequenceNumber", getU64Encoder()],
    ["priceInTicks", getU64Encoder()],
    ["baseLotsRemoved", getU64Encoder()]
  ]);
}
function getExpiredOrderEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["makerId", getAddressDecoder()],
    ["orderSequenceNumber", getU64Decoder()],
    ["priceInTicks", getU64Decoder()],
    ["baseLotsRemoved", getU64Decoder()]
  ]);
}
function getExpiredOrderEventCodec() {
  return combineCodec(
    getExpiredOrderEventEncoder(),
    getExpiredOrderEventDecoder()
  );
}
var FailedMultipleLimitOrderBehavior = /* @__PURE__ */ ((FailedMultipleLimitOrderBehavior3) => {
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["FailOnInsufficientFundsAndAmendOnCross"] = 0] = "FailOnInsufficientFundsAndAmendOnCross";
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["FailOnInsufficientFundsAndFailOnCross"] = 1] = "FailOnInsufficientFundsAndFailOnCross";
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["SkipOnInsufficientFundsAndAmendOnCross"] = 2] = "SkipOnInsufficientFundsAndAmendOnCross";
  FailedMultipleLimitOrderBehavior3[FailedMultipleLimitOrderBehavior3["SkipOnInsufficientFundsAndFailOnCross"] = 3] = "SkipOnInsufficientFundsAndFailOnCross";
  return FailedMultipleLimitOrderBehavior3;
})(FailedMultipleLimitOrderBehavior || {});
function getFailedMultipleLimitOrderBehaviorEncoder() {
  return getEnumEncoder(FailedMultipleLimitOrderBehavior);
}
function getFailedMultipleLimitOrderBehaviorDecoder() {
  return getEnumDecoder(FailedMultipleLimitOrderBehavior);
}
function getFailedMultipleLimitOrderBehaviorCodec() {
  return combineCodec(
    getFailedMultipleLimitOrderBehaviorEncoder(),
    getFailedMultipleLimitOrderBehaviorDecoder()
  );
}
function getFeeEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["feesCollectedInQuoteLots", getU64Encoder()]
  ]);
}
function getFeeEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["feesCollectedInQuoteLots", getU64Decoder()]
  ]);
}
function getFeeEventCodec() {
  return combineCodec(getFeeEventEncoder(), getFeeEventDecoder());
}
function getFIFOOrderIdEncoder() {
  return getStructEncoder([
    ["priceInTicks", getU64Encoder()],
    ["orderSequenceNumber", getU64Encoder()]
  ]);
}
function getFIFOOrderIdDecoder() {
  return getStructDecoder([
    ["priceInTicks", getU64Decoder()],
    ["orderSequenceNumber", getU64Decoder()]
  ]);
}
function getFIFOOrderIdCodec() {
  return combineCodec(getFIFOOrderIdEncoder(), getFIFOOrderIdDecoder());
}
function getFillEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["makerId", getAddressEncoder()],
    ["orderSequenceNumber", getU64Encoder()],
    ["priceInTicks", getU64Encoder()],
    ["baseLotsFilled", getU64Encoder()],
    ["baseLotsRemaining", getU64Encoder()]
  ]);
}
function getFillEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["makerId", getAddressDecoder()],
    ["orderSequenceNumber", getU64Decoder()],
    ["priceInTicks", getU64Decoder()],
    ["baseLotsFilled", getU64Decoder()],
    ["baseLotsRemaining", getU64Decoder()]
  ]);
}
function getFillEventCodec() {
  return combineCodec(getFillEventEncoder(), getFillEventDecoder());
}
function getFillSummaryEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["clientOrderId", getU128Encoder()],
    ["totalBaseLotsFilled", getU64Encoder()],
    ["totalQuoteLotsFilled", getU64Encoder()],
    ["totalFeeInQuoteLots", getU64Encoder()]
  ]);
}
function getFillSummaryEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["clientOrderId", getU128Decoder()],
    ["totalBaseLotsFilled", getU64Decoder()],
    ["totalQuoteLotsFilled", getU64Decoder()],
    ["totalFeeInQuoteLots", getU64Decoder()]
  ]);
}
function getFillSummaryEventCodec() {
  return combineCodec(
    getFillSummaryEventEncoder(),
    getFillSummaryEventDecoder()
  );
}
function getMarketHeaderEncoder() {
  return getStructEncoder([
    ["discriminant", getU64Encoder()],
    ["status", getU64Encoder()],
    ["marketSizeParams", getMarketSizeParamsEncoder()],
    ["baseParams", getTokenParamsEncoder()],
    ["baseLotSize", getU64Encoder()],
    ["quoteParams", getTokenParamsEncoder()],
    ["quoteLotSize", getU64Encoder()],
    ["tickSizeInQuoteAtomsPerBaseUnit", getU64Encoder()],
    ["authority", getAddressEncoder()],
    ["feeRecipient", getAddressEncoder()],
    ["marketSequenceNumber", getU64Encoder()],
    ["successor", getAddressEncoder()],
    ["rawBaseUnitsPerBaseUnit", getU32Encoder()],
    ["padding1", getU32Encoder()],
    ["padding2", getArrayEncoder(getU64Encoder(), { size: 32 })]
  ]);
}
function getMarketHeaderDecoder() {
  return getStructDecoder([
    ["discriminant", getU64Decoder()],
    ["status", getU64Decoder()],
    ["marketSizeParams", getMarketSizeParamsDecoder()],
    ["baseParams", getTokenParamsDecoder()],
    ["baseLotSize", getU64Decoder()],
    ["quoteParams", getTokenParamsDecoder()],
    ["quoteLotSize", getU64Decoder()],
    ["tickSizeInQuoteAtomsPerBaseUnit", getU64Decoder()],
    ["authority", getAddressDecoder()],
    ["feeRecipient", getAddressDecoder()],
    ["marketSequenceNumber", getU64Decoder()],
    ["successor", getAddressDecoder()],
    ["rawBaseUnitsPerBaseUnit", getU32Decoder()],
    ["padding1", getU32Decoder()],
    ["padding2", getArrayDecoder(getU64Decoder(), { size: 32 })]
  ]);
}
function getMarketHeaderCodec() {
  return combineCodec(getMarketHeaderEncoder(), getMarketHeaderDecoder());
}
function getMarketSizeParamsEncoder() {
  return getStructEncoder([
    ["bidsSize", getU64Encoder()],
    ["asksSize", getU64Encoder()],
    ["numSeats", getU64Encoder()]
  ]);
}
function getMarketSizeParamsDecoder() {
  return getStructDecoder([
    ["bidsSize", getU64Decoder()],
    ["asksSize", getU64Decoder()],
    ["numSeats", getU64Decoder()]
  ]);
}
function getMarketSizeParamsCodec() {
  return combineCodec(
    getMarketSizeParamsEncoder(),
    getMarketSizeParamsDecoder()
  );
}
var MarketStatus = /* @__PURE__ */ ((MarketStatus3) => {
  MarketStatus3[MarketStatus3["Uninitialized"] = 0] = "Uninitialized";
  MarketStatus3[MarketStatus3["Active"] = 1] = "Active";
  MarketStatus3[MarketStatus3["PostOnly"] = 2] = "PostOnly";
  MarketStatus3[MarketStatus3["Paused"] = 3] = "Paused";
  MarketStatus3[MarketStatus3["Closed"] = 4] = "Closed";
  MarketStatus3[MarketStatus3["Tombstoned"] = 5] = "Tombstoned";
  return MarketStatus3;
})(MarketStatus || {});
function getMarketStatusEncoder() {
  return getEnumEncoder(MarketStatus);
}
function getMarketStatusDecoder() {
  return getEnumDecoder(MarketStatus);
}
function getMarketStatusCodec() {
  return combineCodec(getMarketStatusEncoder(), getMarketStatusDecoder());
}
function getMultipleOrderPacketEncoder() {
  return getStructEncoder([
    ["bids", getArrayEncoder(getCondensedOrderEncoder())],
    ["asks", getArrayEncoder(getCondensedOrderEncoder())],
    ["clientOrderId", getOptionEncoder(getU128Encoder())],
    [
      "failedMultipleLimitOrderBehavior",
      getFailedMultipleLimitOrderBehaviorEncoder()
    ]
  ]);
}
function getMultipleOrderPacketDecoder() {
  return getStructDecoder([
    ["bids", getArrayDecoder(getCondensedOrderDecoder())],
    ["asks", getArrayDecoder(getCondensedOrderDecoder())],
    ["clientOrderId", getOptionDecoder(getU128Decoder())],
    [
      "failedMultipleLimitOrderBehavior",
      getFailedMultipleLimitOrderBehaviorDecoder()
    ]
  ]);
}
function getMultipleOrderPacketCodec() {
  return combineCodec(
    getMultipleOrderPacketEncoder(),
    getMultipleOrderPacketDecoder()
  );
}
function getOrderPacketEncoder() {
  return getDiscriminatedUnionEncoder([
    [
      "PostOnly",
      getStructEncoder([
        ["side", getSideEncoder()],
        ["priceInTicks", getU64Encoder()],
        ["numBaseLots", getU64Encoder()],
        ["clientOrderId", getU128Encoder()],
        ["rejectPostOnly", getBooleanEncoder()],
        ["useOnlyDepositedFunds", getBooleanEncoder()],
        ["lastValidSlot", getOptionEncoder(getU64Encoder())],
        ["lastValidUnixTimestampInSeconds", getOptionEncoder(getU64Encoder())],
        ["failSilentlyOnInsufficientFunds", getBooleanEncoder()]
      ])
    ],
    [
      "Limit",
      getStructEncoder([
        ["side", getSideEncoder()],
        ["priceInTicks", getU64Encoder()],
        ["numBaseLots", getU64Encoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorEncoder()],
        ["matchLimit", getOptionEncoder(getU64Encoder())],
        ["clientOrderId", getU128Encoder()],
        ["useOnlyDepositedFunds", getBooleanEncoder()],
        ["lastValidSlot", getOptionEncoder(getU64Encoder())],
        ["lastValidUnixTimestampInSeconds", getOptionEncoder(getU64Encoder())],
        ["failSilentlyOnInsufficientFunds", getBooleanEncoder()]
      ])
    ],
    [
      "ImmediateOrCancel",
      getStructEncoder([
        ["side", getSideEncoder()],
        ["priceInTicks", getOptionEncoder(getU64Encoder())],
        ["numBaseLots", getU64Encoder()],
        ["numQuoteLots", getU64Encoder()],
        ["minBaseLotsToFill", getU64Encoder()],
        ["minQuoteLotsToFill", getU64Encoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorEncoder()],
        ["matchLimit", getOptionEncoder(getU64Encoder())],
        ["clientOrderId", getU128Encoder()],
        ["useOnlyDepositedFunds", getBooleanEncoder()],
        ["lastValidSlot", getOptionEncoder(getU64Encoder())],
        ["lastValidUnixTimestampInSeconds", getOptionEncoder(getU64Encoder())]
      ])
    ]
  ]);
}
function getOrderPacketDecoder() {
  return getDiscriminatedUnionDecoder([
    [
      "PostOnly",
      getStructDecoder([
        ["side", getSideDecoder()],
        ["priceInTicks", getU64Decoder()],
        ["numBaseLots", getU64Decoder()],
        ["clientOrderId", getU128Decoder()],
        ["rejectPostOnly", getBooleanDecoder()],
        ["useOnlyDepositedFunds", getBooleanDecoder()],
        ["lastValidSlot", getOptionDecoder(getU64Decoder())],
        ["lastValidUnixTimestampInSeconds", getOptionDecoder(getU64Decoder())],
        ["failSilentlyOnInsufficientFunds", getBooleanDecoder()]
      ])
    ],
    [
      "Limit",
      getStructDecoder([
        ["side", getSideDecoder()],
        ["priceInTicks", getU64Decoder()],
        ["numBaseLots", getU64Decoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorDecoder()],
        ["matchLimit", getOptionDecoder(getU64Decoder())],
        ["clientOrderId", getU128Decoder()],
        ["useOnlyDepositedFunds", getBooleanDecoder()],
        ["lastValidSlot", getOptionDecoder(getU64Decoder())],
        ["lastValidUnixTimestampInSeconds", getOptionDecoder(getU64Decoder())],
        ["failSilentlyOnInsufficientFunds", getBooleanDecoder()]
      ])
    ],
    [
      "ImmediateOrCancel",
      getStructDecoder([
        ["side", getSideDecoder()],
        ["priceInTicks", getOptionDecoder(getU64Decoder())],
        ["numBaseLots", getU64Decoder()],
        ["numQuoteLots", getU64Decoder()],
        ["minBaseLotsToFill", getU64Decoder()],
        ["minQuoteLotsToFill", getU64Decoder()],
        ["selfTradeBehavior", getSelfTradeBehaviorDecoder()],
        ["matchLimit", getOptionDecoder(getU64Decoder())],
        ["clientOrderId", getU128Decoder()],
        ["useOnlyDepositedFunds", getBooleanDecoder()],
        ["lastValidSlot", getOptionDecoder(getU64Decoder())],
        ["lastValidUnixTimestampInSeconds", getOptionDecoder(getU64Decoder())]
      ])
    ]
  ]);
}
function getOrderPacketCodec() {
  return combineCodec(getOrderPacketEncoder(), getOrderPacketDecoder());
}
function orderPacket(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isOrderPacket(kind, value) {
  return value.__kind === kind;
}
function getPhoenixMarketEventEncoder() {
  return getDiscriminatedUnionEncoder([
    ["Uninitialized", getUnitEncoder()],
    [
      "Header",
      getStructEncoder([
        ["fields", getTupleEncoder([getAuditLogHeaderEncoder()])]
      ])
    ],
    [
      "Fill",
      getStructEncoder([["fields", getTupleEncoder([getFillEventEncoder()])]])
    ],
    [
      "Place",
      getStructEncoder([["fields", getTupleEncoder([getPlaceEventEncoder()])]])
    ],
    [
      "Reduce",
      getStructEncoder([
        ["fields", getTupleEncoder([getReduceEventEncoder()])]
      ])
    ],
    [
      "Evict",
      getStructEncoder([["fields", getTupleEncoder([getEvictEventEncoder()])]])
    ],
    [
      "FillSummary",
      getStructEncoder([
        ["fields", getTupleEncoder([getFillSummaryEventEncoder()])]
      ])
    ],
    [
      "Fee",
      getStructEncoder([["fields", getTupleEncoder([getFeeEventEncoder()])]])
    ],
    [
      "TimeInForce",
      getStructEncoder([
        ["fields", getTupleEncoder([getTimeInForceEventEncoder()])]
      ])
    ],
    [
      "ExpiredOrder",
      getStructEncoder([
        ["fields", getTupleEncoder([getExpiredOrderEventEncoder()])]
      ])
    ]
  ]);
}
function getPhoenixMarketEventDecoder() {
  return getDiscriminatedUnionDecoder([
    ["Uninitialized", getUnitDecoder()],
    [
      "Header",
      getStructDecoder([
        ["fields", getTupleDecoder([getAuditLogHeaderDecoder()])]
      ])
    ],
    [
      "Fill",
      getStructDecoder([["fields", getTupleDecoder([getFillEventDecoder()])]])
    ],
    [
      "Place",
      getStructDecoder([["fields", getTupleDecoder([getPlaceEventDecoder()])]])
    ],
    [
      "Reduce",
      getStructDecoder([
        ["fields", getTupleDecoder([getReduceEventDecoder()])]
      ])
    ],
    [
      "Evict",
      getStructDecoder([["fields", getTupleDecoder([getEvictEventDecoder()])]])
    ],
    [
      "FillSummary",
      getStructDecoder([
        ["fields", getTupleDecoder([getFillSummaryEventDecoder()])]
      ])
    ],
    [
      "Fee",
      getStructDecoder([["fields", getTupleDecoder([getFeeEventDecoder()])]])
    ],
    [
      "TimeInForce",
      getStructDecoder([
        ["fields", getTupleDecoder([getTimeInForceEventDecoder()])]
      ])
    ],
    [
      "ExpiredOrder",
      getStructDecoder([
        ["fields", getTupleDecoder([getExpiredOrderEventDecoder()])]
      ])
    ]
  ]);
}
function getPhoenixMarketEventCodec() {
  return combineCodec(
    getPhoenixMarketEventEncoder(),
    getPhoenixMarketEventDecoder()
  );
}
function phoenixMarketEvent(kind, data) {
  return Array.isArray(data) ? { __kind: kind, fields: data } : { __kind: kind, ...data ?? {} };
}
function isPhoenixMarketEvent(kind, value) {
  return value.__kind === kind;
}
function getPlaceEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["orderSequenceNumber", getU64Encoder()],
    ["clientOrderId", getU128Encoder()],
    ["priceInTicks", getU64Encoder()],
    ["baseLotsPlaced", getU64Encoder()]
  ]);
}
function getPlaceEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["orderSequenceNumber", getU64Decoder()],
    ["clientOrderId", getU128Decoder()],
    ["priceInTicks", getU64Decoder()],
    ["baseLotsPlaced", getU64Decoder()]
  ]);
}
function getPlaceEventCodec() {
  return combineCodec(getPlaceEventEncoder(), getPlaceEventDecoder());
}
function getReduceEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["orderSequenceNumber", getU64Encoder()],
    ["priceInTicks", getU64Encoder()],
    ["baseLotsRemoved", getU64Encoder()],
    ["baseLotsRemaining", getU64Encoder()]
  ]);
}
function getReduceEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["orderSequenceNumber", getU64Decoder()],
    ["priceInTicks", getU64Decoder()],
    ["baseLotsRemoved", getU64Decoder()],
    ["baseLotsRemaining", getU64Decoder()]
  ]);
}
function getReduceEventCodec() {
  return combineCodec(getReduceEventEncoder(), getReduceEventDecoder());
}
function getReduceOrderParamsEncoder() {
  return getStructEncoder([
    ["baseParams", getCancelOrderParamsEncoder()],
    ["size", getU64Encoder()]
  ]);
}
function getReduceOrderParamsDecoder() {
  return getStructDecoder([
    ["baseParams", getCancelOrderParamsDecoder()],
    ["size", getU64Decoder()]
  ]);
}
function getReduceOrderParamsCodec() {
  return combineCodec(
    getReduceOrderParamsEncoder(),
    getReduceOrderParamsDecoder()
  );
}
function getSeatEncoder() {
  return getStructEncoder([
    ["discriminant", getU64Encoder()],
    ["market", getAddressEncoder()],
    ["trader", getAddressEncoder()],
    ["approvalStatus", getU64Encoder()],
    ["padding", getArrayEncoder(getU64Encoder(), { size: 6 })]
  ]);
}
function getSeatDecoder() {
  return getStructDecoder([
    ["discriminant", getU64Decoder()],
    ["market", getAddressDecoder()],
    ["trader", getAddressDecoder()],
    ["approvalStatus", getU64Decoder()],
    ["padding", getArrayDecoder(getU64Decoder(), { size: 6 })]
  ]);
}
function getSeatCodec() {
  return combineCodec(getSeatEncoder(), getSeatDecoder());
}
var SeatApprovalStatus = /* @__PURE__ */ ((SeatApprovalStatus3) => {
  SeatApprovalStatus3[SeatApprovalStatus3["NotApproved"] = 0] = "NotApproved";
  SeatApprovalStatus3[SeatApprovalStatus3["Approved"] = 1] = "Approved";
  SeatApprovalStatus3[SeatApprovalStatus3["Retired"] = 2] = "Retired";
  return SeatApprovalStatus3;
})(SeatApprovalStatus || {});
function getSeatApprovalStatusEncoder() {
  return getEnumEncoder(SeatApprovalStatus);
}
function getSeatApprovalStatusDecoder() {
  return getEnumDecoder(SeatApprovalStatus);
}
function getSeatApprovalStatusCodec() {
  return combineCodec(
    getSeatApprovalStatusEncoder(),
    getSeatApprovalStatusDecoder()
  );
}
var SelfTradeBehavior2 = /* @__PURE__ */ ((SelfTradeBehavior3) => {
  SelfTradeBehavior3[SelfTradeBehavior3["Abort"] = 0] = "Abort";
  SelfTradeBehavior3[SelfTradeBehavior3["CancelProvide"] = 1] = "CancelProvide";
  SelfTradeBehavior3[SelfTradeBehavior3["DecrementTake"] = 2] = "DecrementTake";
  return SelfTradeBehavior3;
})(SelfTradeBehavior2 || {});
function getSelfTradeBehaviorEncoder() {
  return getEnumEncoder(SelfTradeBehavior2);
}
function getSelfTradeBehaviorDecoder() {
  return getEnumDecoder(SelfTradeBehavior2);
}
function getSelfTradeBehaviorCodec() {
  return combineCodec(
    getSelfTradeBehaviorEncoder(),
    getSelfTradeBehaviorDecoder()
  );
}
var Side4 = /* @__PURE__ */ ((Side5) => {
  Side5[Side5["Bid"] = 0] = "Bid";
  Side5[Side5["Ask"] = 1] = "Ask";
  return Side5;
})(Side4 || {});
function getSideEncoder() {
  return getEnumEncoder(Side4);
}
function getSideDecoder() {
  return getEnumDecoder(Side4);
}
function getSideCodec() {
  return combineCodec(getSideEncoder(), getSideDecoder());
}
function getTimeInForceEventEncoder() {
  return getStructEncoder([
    ["index", getU16Encoder()],
    ["orderSequenceNumber", getU64Encoder()],
    ["lastValidSlot", getU64Encoder()],
    ["lastValidUnixTimestampInSeconds", getU64Encoder()]
  ]);
}
function getTimeInForceEventDecoder() {
  return getStructDecoder([
    ["index", getU16Decoder()],
    ["orderSequenceNumber", getU64Decoder()],
    ["lastValidSlot", getU64Decoder()],
    ["lastValidUnixTimestampInSeconds", getU64Decoder()]
  ]);
}
function getTimeInForceEventCodec() {
  return combineCodec(
    getTimeInForceEventEncoder(),
    getTimeInForceEventDecoder()
  );
}
function getTokenParamsEncoder() {
  return getStructEncoder([
    ["decimals", getU32Encoder()],
    ["vaultBump", getU32Encoder()],
    ["mintKey", getAddressEncoder()],
    ["vaultKey", getAddressEncoder()]
  ]);
}
function getTokenParamsDecoder() {
  return getStructDecoder([
    ["decimals", getU32Decoder()],
    ["vaultBump", getU32Decoder()],
    ["mintKey", getAddressDecoder()],
    ["vaultKey", getAddressDecoder()]
  ]);
}
function getTokenParamsCodec() {
  return combineCodec(getTokenParamsEncoder(), getTokenParamsDecoder());
}

// src/generated/instructions/cancelMultipleOrdersById.ts
function getCancelMultipleOrdersByIdInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getCancelMultipleOrdersByIdParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 10 })
  );
}
function getCancelMultipleOrdersByIdInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getCancelMultipleOrdersByIdParamsDecoder()]
  ]);
}
function getCancelMultipleOrdersByIdInstructionDataCodec() {
  return combineCodec(
    getCancelMultipleOrdersByIdInstructionDataEncoder(),
    getCancelMultipleOrdersByIdInstructionDataDecoder()
  );
}
function getCancelMultipleOrdersByIdInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCancelMultipleOrdersByIdInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelMultipleOrdersByIdInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCancelMultipleOrdersByIdInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getCancelMultipleOrdersByIdParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 11 })
  );
}
function getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getCancelMultipleOrdersByIdParamsDecoder()]
  ]);
}
function getCancelMultipleOrdersByIdWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder(),
    getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder()
  );
}
function getCancelMultipleOrdersByIdWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelMultipleOrdersByIdWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getCancelUpToInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getCancelUpToParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 8 })
  );
}
function getCancelUpToInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getCancelUpToParamsDecoder()]
  ]);
}
function getCancelUpToInstructionDataCodec() {
  return combineCodec(
    getCancelUpToInstructionDataEncoder(),
    getCancelUpToInstructionDataDecoder()
  );
}
function getCancelUpToInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCancelUpToInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelUpToInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCancelUpToInstructionDataDecoder().decode(instruction.data)
  };
}
function getCancelUpToWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getCancelUpToParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 9 })
  );
}
function getCancelUpToWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getCancelUpToParamsDecoder()]
  ]);
}
function getCancelUpToWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getCancelUpToWithFreeFundsInstructionDataEncoder(),
    getCancelUpToWithFreeFundsInstructionDataDecoder()
  );
}
function getCancelUpToWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getCancelUpToWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseCancelUpToWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getCancelUpToWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getChangeFeeRecipientInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 109 })
  );
}
function getChangeFeeRecipientInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getChangeFeeRecipientInstructionDataCodec() {
  return combineCodec(
    getChangeFeeRecipientInstructionDataEncoder(),
    getChangeFeeRecipientInstructionDataDecoder()
  );
}
function getChangeFeeRecipientInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    newFeeRecipient: {
      value: input.newFeeRecipient ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.newFeeRecipient)
    ],
    programAddress,
    data: getChangeFeeRecipientInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseChangeFeeRecipientInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      newFeeRecipient: getNextAccount()
    },
    data: getChangeFeeRecipientInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getChangeMarketStatusInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["marketStatus", getMarketStatusEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 103 })
  );
}
function getChangeMarketStatusInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["marketStatus", getMarketStatusDecoder()]
  ]);
}
function getChangeMarketStatusInstructionDataCodec() {
  return combineCodec(
    getChangeMarketStatusInstructionDataEncoder(),
    getChangeMarketStatusInstructionDataDecoder()
  );
}
function getChangeMarketStatusInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority)
    ],
    programAddress,
    data: getChangeMarketStatusInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseChangeMarketStatusInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount()
    },
    data: getChangeMarketStatusInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getChangeSeatStatusInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["approvalStatus", getSeatApprovalStatusEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 104 })
  );
}
function getChangeSeatStatusInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["approvalStatus", getSeatApprovalStatusDecoder()]
  ]);
}
function getChangeSeatStatusInstructionDataCodec() {
  return combineCodec(
    getChangeSeatStatusInstructionDataEncoder(),
    getChangeSeatStatusInstructionDataDecoder()
  );
}
function getChangeSeatStatusInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    seat: { value: input.seat ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getChangeSeatStatusInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseChangeSeatStatusInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      seat: getNextAccount()
    },
    data: getChangeSeatStatusInstructionDataDecoder().decode(instruction.data)
  };
}
function getClaimAuthorityInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 101 })
  );
}
function getClaimAuthorityInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getClaimAuthorityInstructionDataCodec() {
  return combineCodec(
    getClaimAuthorityInstructionDataEncoder(),
    getClaimAuthorityInstructionDataDecoder()
  );
}
function getClaimAuthorityInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    successor: { value: input.successor ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.successor)
    ],
    programAddress,
    data: getClaimAuthorityInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseClaimAuthorityInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      successor: getNextAccount()
    },
    data: getClaimAuthorityInstructionDataDecoder().decode(instruction.data)
  };
}
function getCollectFeesInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 108 })
  );
}
function getCollectFeesInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getCollectFeesInstructionDataCodec() {
  return combineCodec(
    getCollectFeesInstructionDataEncoder(),
    getCollectFeesInstructionDataDecoder()
  );
}
function getCollectFeesInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    sweeper: { value: input.sweeper ?? null, isWritable: false },
    feeRecipient: { value: input.feeRecipient ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.sweeper),
      getAccountMeta(accounts.feeRecipient),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getCollectFeesInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseCollectFeesInstruction(instruction) {
  if (instruction.accounts.length < 7) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      sweeper: getNextAccount(),
      feeRecipient: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getCollectFeesInstructionDataDecoder().decode(instruction.data)
  };
}
function getDepositFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["quoteLotsToDeposit", getU64Encoder()],
      ["baseLotsToDeposit", getU64Encoder()]
    ]),
    (value) => ({ ...value, discriminator: 13 })
  );
}
function getDepositFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["quoteLotsToDeposit", getU64Decoder()],
    ["baseLotsToDeposit", getU64Decoder()]
  ]);
}
function getDepositFundsInstructionDataCodec() {
  return combineCodec(
    getDepositFundsInstructionDataEncoder(),
    getDepositFundsInstructionDataDecoder()
  );
}
function getDepositFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getDepositFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseDepositFundsInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getDepositFundsInstructionDataDecoder().decode(instruction.data)
  };
}
function getEvictSeatInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 106 })
  );
}
function getEvictSeatInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getEvictSeatInstructionDataCodec() {
  return combineCodec(
    getEvictSeatInstructionDataEncoder(),
    getEvictSeatInstructionDataDecoder()
  );
}
function getEvictSeatInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getEvictSeatInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseEvictSeatInstruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getEvictSeatInstructionDataDecoder().decode(instruction.data)
  };
}
function getForceCancelOrdersInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getCancelUpToParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 107 })
  );
}
function getForceCancelOrdersInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getCancelUpToParamsDecoder()]
  ]);
}
function getForceCancelOrdersInstructionDataCodec() {
  return combineCodec(
    getForceCancelOrdersInstructionDataEncoder(),
    getForceCancelOrdersInstructionDataDecoder()
  );
}
function getForceCancelOrdersInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getForceCancelOrdersInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseForceCancelOrdersInstruction(instruction) {
  if (instruction.accounts.length < 11) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getForceCancelOrdersInstructionDataDecoder().decode(instruction.data)
  };
}
function getInitializeMarketInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["marketSizeParams", getMarketSizeParamsEncoder()],
      ["numQuoteLotsPerQuoteUnit", getU64Encoder()],
      ["tickSizeInQuoteLotsPerBaseUnit", getU64Encoder()],
      ["numBaseLotsPerBaseUnit", getU64Encoder()],
      ["takerFeeBps", getU16Encoder()],
      ["feeCollector", getAddressEncoder()],
      ["rawBaseUnitsPerBaseUnit", getOptionEncoder(getU32Encoder())]
    ]),
    (value) => ({ ...value, discriminator: 100 })
  );
}
function getInitializeMarketInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["marketSizeParams", getMarketSizeParamsDecoder()],
    ["numQuoteLotsPerQuoteUnit", getU64Decoder()],
    ["tickSizeInQuoteLotsPerBaseUnit", getU64Decoder()],
    ["numBaseLotsPerBaseUnit", getU64Decoder()],
    ["takerFeeBps", getU16Decoder()],
    ["feeCollector", getAddressDecoder()],
    ["rawBaseUnitsPerBaseUnit", getOptionDecoder(getU32Decoder())]
  ]);
}
function getInitializeMarketInstructionDataCodec() {
  return combineCodec(
    getInitializeMarketInstructionDataEncoder(),
    getInitializeMarketInstructionDataDecoder()
  );
}
function getInitializeMarketInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketCreator: { value: input.marketCreator ?? null, isWritable: true },
    baseMint: { value: input.baseMint ?? null, isWritable: false },
    quoteMint: { value: input.quoteMint ?? null, isWritable: false },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketCreator),
      getAccountMeta(accounts.baseMint),
      getAccountMeta(accounts.quoteMint),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.systemProgram),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getInitializeMarketInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseInitializeMarketInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketCreator: getNextAccount(),
      baseMint: getNextAccount(),
      quoteMint: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      systemProgram: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getInitializeMarketInstructionDataDecoder().decode(instruction.data)
  };
}
function getLogInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 15 })
  );
}
function getLogInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getLogInstructionDataCodec() {
  return combineCodec(
    getLogInstructionDataEncoder(),
    getLogInstructionDataDecoder()
  );
}
function getLogInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    logAuthority: { value: input.logAuthority ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [getAccountMeta(accounts.logAuthority)],
    programAddress,
    data: getLogInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseLogInstruction(instruction) {
  if (instruction.accounts.length < 1) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      logAuthority: getNextAccount()
    },
    data: getLogInstructionDataDecoder().decode(instruction.data)
  };
}
function getNameSuccessorInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["successor", getAddressEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 102 })
  );
}
function getNameSuccessorInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["successor", getAddressDecoder()]
  ]);
}
function getNameSuccessorInstructionDataCodec() {
  return combineCodec(
    getNameSuccessorInstructionDataEncoder(),
    getNameSuccessorInstructionDataDecoder()
  );
}
function getNameSuccessorInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority)
    ],
    programAddress,
    data: getNameSuccessorInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseNameSuccessorInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount()
    },
    data: getNameSuccessorInstructionDataDecoder().decode(instruction.data)
  };
}
function getPlaceLimitOrderInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 2 })
  );
}
function getPlaceLimitOrderInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getPlaceLimitOrderInstructionDataCodec() {
  return combineCodec(
    getPlaceLimitOrderInstructionDataEncoder(),
    getPlaceLimitOrderInstructionDataDecoder()
  );
}
function getPlaceLimitOrderInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getPlaceLimitOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceLimitOrderInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getPlaceLimitOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getPlaceLimitOrderWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 3 })
  );
}
function getPlaceLimitOrderWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getPlaceLimitOrderWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getPlaceLimitOrderWithFreeFundsInstructionDataEncoder(),
    getPlaceLimitOrderWithFreeFundsInstructionDataDecoder()
  );
}
function getPlaceLimitOrderWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getPlaceLimitOrderWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceLimitOrderWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount()
    },
    data: getPlaceLimitOrderWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getPlaceMultiplePostOnlyOrdersInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["multipleOrderPacket", getMultipleOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 16 })
  );
}
function getPlaceMultiplePostOnlyOrdersInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["multipleOrderPacket", getMultipleOrderPacketDecoder()]
  ]);
}
function getPlaceMultiplePostOnlyOrdersInstructionDataCodec() {
  return combineCodec(
    getPlaceMultiplePostOnlyOrdersInstructionDataEncoder(),
    getPlaceMultiplePostOnlyOrdersInstructionDataDecoder()
  );
}
function getPlaceMultiplePostOnlyOrdersInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getPlaceMultiplePostOnlyOrdersInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceMultiplePostOnlyOrdersInstruction(instruction) {
  if (instruction.accounts.length < 10) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getPlaceMultiplePostOnlyOrdersInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["multipleOrderPacket", getMultipleOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 17 })
  );
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["multipleOrderPacket", getMultipleOrderPacketDecoder()]
  ]);
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder(),
    getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder()
  );
}
function getPlaceMultiplePostOnlyOrdersWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parsePlaceMultiplePostOnlyOrdersWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount()
    },
    data: getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getReduceOrderInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getReduceOrderParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 4 })
  );
}
function getReduceOrderInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getReduceOrderParamsDecoder()]
  ]);
}
function getReduceOrderInstructionDataCodec() {
  return combineCodec(
    getReduceOrderInstructionDataEncoder(),
    getReduceOrderInstructionDataDecoder()
  );
}
function getReduceOrderInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getReduceOrderInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseReduceOrderInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getReduceOrderInstructionDataDecoder().decode(instruction.data)
  };
}
function getReduceOrderWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["params", getReduceOrderParamsEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 5 })
  );
}
function getReduceOrderWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["params", getReduceOrderParamsDecoder()]
  ]);
}
function getReduceOrderWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getReduceOrderWithFreeFundsInstructionDataEncoder(),
    getReduceOrderWithFreeFundsInstructionDataDecoder()
  );
}
function getReduceOrderWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: true }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader)
    ],
    programAddress,
    data: getReduceOrderWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseReduceOrderWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 4) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount()
    },
    data: getReduceOrderWithFreeFundsInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getRequestSeatInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 14 })
  );
}
function getRequestSeatInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getRequestSeatInstructionDataCodec() {
  return combineCodec(
    getRequestSeatInstructionDataEncoder(),
    getRequestSeatInstructionDataDecoder()
  );
}
function getRequestSeatInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    payer: { value: input.payer ?? null, isWritable: true },
    seat: { value: input.seat ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getRequestSeatInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRequestSeatInstruction(instruction) {
  if (instruction.accounts.length < 6) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      payer: getNextAccount(),
      seat: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getRequestSeatInstructionDataDecoder().decode(instruction.data)
  };
}
function getRequestSeatAuthorizedInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([["discriminator", getU8Encoder()]]),
    (value) => ({ ...value, discriminator: 105 })
  );
}
function getRequestSeatAuthorizedInstructionDataDecoder() {
  return getStructDecoder([["discriminator", getU8Decoder()]]);
}
function getRequestSeatAuthorizedInstructionDataCodec() {
  return combineCodec(
    getRequestSeatAuthorizedInstructionDataEncoder(),
    getRequestSeatAuthorizedInstructionDataDecoder()
  );
}
function getRequestSeatAuthorizedInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    marketAuthority: {
      value: input.marketAuthority ?? null,
      isWritable: false
    },
    payer: { value: input.payer ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: true },
    systemProgram: { value: input.systemProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  if (!accounts.systemProgram.value) {
    accounts.systemProgram.value = "11111111111111111111111111111111";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.marketAuthority),
      getAccountMeta(accounts.payer),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat),
      getAccountMeta(accounts.systemProgram)
    ],
    programAddress,
    data: getRequestSeatAuthorizedInstructionDataEncoder().encode({})
  };
  return instruction;
}
function parseRequestSeatAuthorizedInstruction(instruction) {
  if (instruction.accounts.length < 8) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      marketAuthority: getNextAccount(),
      payer: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount(),
      systemProgram: getNextAccount()
    },
    data: getRequestSeatAuthorizedInstructionDataDecoder().decode(
      instruction.data
    )
  };
}
function getSwapInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 0 })
  );
}
function getSwapInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getSwapInstructionDataCodec() {
  return combineCodec(
    getSwapInstructionDataEncoder(),
    getSwapInstructionDataDecoder()
  );
}
function getSwapInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getSwapInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSwapInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getSwapInstructionDataDecoder().decode(instruction.data)
  };
}
function getSwapWithFreeFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["orderPacket", getOrderPacketEncoder()]
    ]),
    (value) => ({ ...value, discriminator: 1 })
  );
}
function getSwapWithFreeFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["orderPacket", getOrderPacketDecoder()]
  ]);
}
function getSwapWithFreeFundsInstructionDataCodec() {
  return combineCodec(
    getSwapWithFreeFundsInstructionDataEncoder(),
    getSwapWithFreeFundsInstructionDataDecoder()
  );
}
function getSwapWithFreeFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    seat: { value: input.seat ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.seat)
    ],
    programAddress,
    data: getSwapWithFreeFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseSwapWithFreeFundsInstruction(instruction) {
  if (instruction.accounts.length < 5) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      seat: getNextAccount()
    },
    data: getSwapWithFreeFundsInstructionDataDecoder().decode(instruction.data)
  };
}
function getWithdrawFundsInstructionDataEncoder() {
  return transformEncoder(
    getStructEncoder([
      ["discriminator", getU8Encoder()],
      ["quoteLotsToWithdraw", getOptionEncoder(getU64Encoder())],
      ["baseLotsToWithdraw", getOptionEncoder(getU64Encoder())]
    ]),
    (value) => ({ ...value, discriminator: 12 })
  );
}
function getWithdrawFundsInstructionDataDecoder() {
  return getStructDecoder([
    ["discriminator", getU8Decoder()],
    ["quoteLotsToWithdraw", getOptionDecoder(getU64Decoder())],
    ["baseLotsToWithdraw", getOptionDecoder(getU64Decoder())]
  ]);
}
function getWithdrawFundsInstructionDataCodec() {
  return combineCodec(
    getWithdrawFundsInstructionDataEncoder(),
    getWithdrawFundsInstructionDataDecoder()
  );
}
function getWithdrawFundsInstruction(input) {
  const programAddress = PHOENIX_V1_PROGRAM_ADDRESS;
  const originalAccounts = {
    phoenixProgram: { value: input.phoenixProgram ?? null, isWritable: false },
    logAuthority: { value: input.logAuthority ?? null, isWritable: false },
    market: { value: input.market ?? null, isWritable: true },
    trader: { value: input.trader ?? null, isWritable: false },
    baseAccount: { value: input.baseAccount ?? null, isWritable: true },
    quoteAccount: { value: input.quoteAccount ?? null, isWritable: true },
    baseVault: { value: input.baseVault ?? null, isWritable: true },
    quoteVault: { value: input.quoteVault ?? null, isWritable: true },
    tokenProgram: { value: input.tokenProgram ?? null, isWritable: false }
  };
  const accounts = originalAccounts;
  const args = { ...input };
  if (!accounts.tokenProgram.value) {
    accounts.tokenProgram.value = "TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA";
  }
  const getAccountMeta = getAccountMetaFactory(programAddress);
  const instruction = {
    accounts: [
      getAccountMeta(accounts.phoenixProgram),
      getAccountMeta(accounts.logAuthority),
      getAccountMeta(accounts.market),
      getAccountMeta(accounts.trader),
      getAccountMeta(accounts.baseAccount),
      getAccountMeta(accounts.quoteAccount),
      getAccountMeta(accounts.baseVault),
      getAccountMeta(accounts.quoteVault),
      getAccountMeta(accounts.tokenProgram)
    ],
    programAddress,
    data: getWithdrawFundsInstructionDataEncoder().encode(
      args
    )
  };
  return instruction;
}
function parseWithdrawFundsInstruction(instruction) {
  if (instruction.accounts.length < 9) {
    throw new Error("Not enough accounts");
  }
  let accountIndex = 0;
  const getNextAccount = () => {
    const accountMeta = instruction.accounts[accountIndex];
    accountIndex += 1;
    return accountMeta;
  };
  return {
    programAddress: instruction.programAddress,
    accounts: {
      phoenixProgram: getNextAccount(),
      logAuthority: getNextAccount(),
      market: getNextAccount(),
      trader: getNextAccount(),
      baseAccount: getNextAccount(),
      quoteAccount: getNextAccount(),
      baseVault: getNextAccount(),
      quoteVault: getNextAccount(),
      tokenProgram: getNextAccount()
    },
    data: getWithdrawFundsInstructionDataDecoder().decode(instruction.data)
  };
}

// src/helpers/market.ts
var MIN_MARKET_SIZE_PARAMS = {
  bidsSize: 512n,
  asksSize: 512n,
  numSeats: 128n
};
var MIN_MARKET_SIZE = 84368n;
var MARKET_HEADER_SIZE = 576n;
var MarketState = class {
  address;
  data;
  constructor(address, data) {
    this.address = address;
    this.data = data;
  }
  // static load(address: Address, buffer: Buffer): Promise<MarketState> {
  //   const marketData = deserializeMarketData(buffer);
  //   return new MarketState(address, data.value);
  // }
};

// src/helpers/index.ts
async function getLogAuthority() {
  const programAddress = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [getUtf8Encoder().encode("log")]
  });
}
async function findMintVaultPda(seeds) {
  const programAddress = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("vault"),
      getAddressEncoder().encode(seeds.market),
      getAddressEncoder().encode(seeds.mint)
    ]
  });
}
async function findSeatPda(seeds) {
  const programAddress = "PhoeNiXZ8ByJGLkxNfZRnkUfjvmuYqLR89jjFHGqdXY";
  return await getProgramDerivedAddress({
    programAddress,
    seeds: [
      getUtf8Encoder().encode("seat"),
      getAddressEncoder().encode(seeds.market),
      getAddressEncoder().encode(seeds.trader)
    ]
  });
}

export { FailedMultipleLimitOrderBehavior, MARKET_HEADER_SIZE, MIN_MARKET_SIZE, MIN_MARKET_SIZE_PARAMS, MarketState, MarketStatus, PHOENIX_V1_ERROR__CANCEL_MULTIPLE_ORDERS_ERROR, PHOENIX_V1_ERROR__EVICTION_ERROR, PHOENIX_V1_ERROR__FAILED_TO_FLUSH_BUFFER, PHOENIX_V1_ERROR__FAILED_TO_LOAD_MARKET_FROM_ACCOUNT, PHOENIX_V1_ERROR__FAILED_TO_SERIALIZE_EVENT, PHOENIX_V1_ERROR__INVALID_BASE_ACCOUNT, PHOENIX_V1_ERROR__INVALID_BASE_VAULT, PHOENIX_V1_ERROR__INVALID_LOT_SIZE, PHOENIX_V1_ERROR__INVALID_MARKET_AUTHORITY, PHOENIX_V1_ERROR__INVALID_MARKET_PARAMETERS, PHOENIX_V1_ERROR__INVALID_MARKET_SIGNER, PHOENIX_V1_ERROR__INVALID_MINT, PHOENIX_V1_ERROR__INVALID_QUOTE_ACCOUNT, PHOENIX_V1_ERROR__INVALID_QUOTE_VAULT, PHOENIX_V1_ERROR__INVALID_SEAT_STATUS, PHOENIX_V1_ERROR__INVALID_STATE_TRANSITION, PHOENIX_V1_ERROR__INVALID_TICK_SIZE, PHOENIX_V1_ERROR__MARKET_ALREADY_INITIALIZED, PHOENIX_V1_ERROR__MARKET_UNINITIALIZED, PHOENIX_V1_ERROR__NEW_ORDER_ERROR, PHOENIX_V1_ERROR__NON_EMPTY_SCRATCH_BUFFER, PHOENIX_V1_ERROR__REDUCE_ORDER_ERROR, PHOENIX_V1_ERROR__REMOVE_EMPTY_ORDERS_ERROR, PHOENIX_V1_ERROR__TOO_MANY_EVENTS, PHOENIX_V1_ERROR__TRADER_NOT_FOUND, PHOENIX_V1_ERROR__WITHDRAW_FUNDS_ERROR, PHOENIX_V1_PROGRAM_ADDRESS, PhoenixV1Instruction, SeatApprovalStatus, SelfTradeBehavior2 as SelfTradeBehavior, Side4 as Side, findMintVaultPda, findSeatPda, getAuditLogHeaderCodec, getAuditLogHeaderDecoder, getAuditLogHeaderEncoder, getCancelAllOrdersInstruction, getCancelAllOrdersInstructionDataCodec, getCancelAllOrdersInstructionDataDecoder, getCancelAllOrdersInstructionDataEncoder, getCancelAllOrdersWithFreeFundsInstruction, getCancelAllOrdersWithFreeFundsInstructionDataCodec, getCancelAllOrdersWithFreeFundsInstructionDataDecoder, getCancelAllOrdersWithFreeFundsInstructionDataEncoder, getCancelMultipleOrdersByIdInstruction, getCancelMultipleOrdersByIdInstructionDataCodec, getCancelMultipleOrdersByIdInstructionDataDecoder, getCancelMultipleOrdersByIdInstructionDataEncoder, getCancelMultipleOrdersByIdParamsCodec, getCancelMultipleOrdersByIdParamsDecoder, getCancelMultipleOrdersByIdParamsEncoder, getCancelMultipleOrdersByIdWithFreeFundsInstruction, getCancelMultipleOrdersByIdWithFreeFundsInstructionDataCodec, getCancelMultipleOrdersByIdWithFreeFundsInstructionDataDecoder, getCancelMultipleOrdersByIdWithFreeFundsInstructionDataEncoder, getCancelOrderParamsCodec, getCancelOrderParamsDecoder, getCancelOrderParamsEncoder, getCancelUpToInstruction, getCancelUpToInstructionDataCodec, getCancelUpToInstructionDataDecoder, getCancelUpToInstructionDataEncoder, getCancelUpToParamsCodec, getCancelUpToParamsDecoder, getCancelUpToParamsEncoder, getCancelUpToWithFreeFundsInstruction, getCancelUpToWithFreeFundsInstructionDataCodec, getCancelUpToWithFreeFundsInstructionDataDecoder, getCancelUpToWithFreeFundsInstructionDataEncoder, getChangeFeeRecipientInstruction, getChangeFeeRecipientInstructionDataCodec, getChangeFeeRecipientInstructionDataDecoder, getChangeFeeRecipientInstructionDataEncoder, getChangeMarketStatusInstruction, getChangeMarketStatusInstructionDataCodec, getChangeMarketStatusInstructionDataDecoder, getChangeMarketStatusInstructionDataEncoder, getChangeSeatStatusInstruction, getChangeSeatStatusInstructionDataCodec, getChangeSeatStatusInstructionDataDecoder, getChangeSeatStatusInstructionDataEncoder, getClaimAuthorityInstruction, getClaimAuthorityInstructionDataCodec, getClaimAuthorityInstructionDataDecoder, getClaimAuthorityInstructionDataEncoder, getCollectFeesInstruction, getCollectFeesInstructionDataCodec, getCollectFeesInstructionDataDecoder, getCollectFeesInstructionDataEncoder, getCondensedOrderCodec, getCondensedOrderDecoder, getCondensedOrderEncoder, getDepositFundsInstruction, getDepositFundsInstructionDataCodec, getDepositFundsInstructionDataDecoder, getDepositFundsInstructionDataEncoder, getEvictEventCodec, getEvictEventDecoder, getEvictEventEncoder, getEvictSeatInstruction, getEvictSeatInstructionDataCodec, getEvictSeatInstructionDataDecoder, getEvictSeatInstructionDataEncoder, getExpiredOrderEventCodec, getExpiredOrderEventDecoder, getExpiredOrderEventEncoder, getFIFOOrderIdCodec, getFIFOOrderIdDecoder, getFIFOOrderIdEncoder, getFailedMultipleLimitOrderBehaviorCodec, getFailedMultipleLimitOrderBehaviorDecoder, getFailedMultipleLimitOrderBehaviorEncoder, getFeeEventCodec, getFeeEventDecoder, getFeeEventEncoder, getFillEventCodec, getFillEventDecoder, getFillEventEncoder, getFillSummaryEventCodec, getFillSummaryEventDecoder, getFillSummaryEventEncoder, getForceCancelOrdersInstruction, getForceCancelOrdersInstructionDataCodec, getForceCancelOrdersInstructionDataDecoder, getForceCancelOrdersInstructionDataEncoder, getInitializeMarketInstruction, getInitializeMarketInstructionDataCodec, getInitializeMarketInstructionDataDecoder, getInitializeMarketInstructionDataEncoder, getLogAuthority, getLogInstruction, getLogInstructionDataCodec, getLogInstructionDataDecoder, getLogInstructionDataEncoder, getMarketHeaderCodec, getMarketHeaderDecoder, getMarketHeaderEncoder, getMarketSizeParamsCodec, getMarketSizeParamsDecoder, getMarketSizeParamsEncoder, getMarketStatusCodec, getMarketStatusDecoder, getMarketStatusEncoder, getMultipleOrderPacketCodec, getMultipleOrderPacketDecoder, getMultipleOrderPacketEncoder, getNameSuccessorInstruction, getNameSuccessorInstructionDataCodec, getNameSuccessorInstructionDataDecoder, getNameSuccessorInstructionDataEncoder, getOrderPacketCodec, getOrderPacketDecoder, getOrderPacketEncoder, getPhoenixMarketEventCodec, getPhoenixMarketEventDecoder, getPhoenixMarketEventEncoder, getPhoenixV1ErrorMessage, getPlaceEventCodec, getPlaceEventDecoder, getPlaceEventEncoder, getPlaceLimitOrderInstruction, getPlaceLimitOrderInstructionDataCodec, getPlaceLimitOrderInstructionDataDecoder, getPlaceLimitOrderInstructionDataEncoder, getPlaceLimitOrderWithFreeFundsInstruction, getPlaceLimitOrderWithFreeFundsInstructionDataCodec, getPlaceLimitOrderWithFreeFundsInstructionDataDecoder, getPlaceLimitOrderWithFreeFundsInstructionDataEncoder, getPlaceMultiplePostOnlyOrdersInstruction, getPlaceMultiplePostOnlyOrdersInstructionDataCodec, getPlaceMultiplePostOnlyOrdersInstructionDataDecoder, getPlaceMultiplePostOnlyOrdersInstructionDataEncoder, getPlaceMultiplePostOnlyOrdersWithFreeFundsInstruction, getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataCodec, getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataDecoder, getPlaceMultiplePostOnlyOrdersWithFreeFundsInstructionDataEncoder, getReduceEventCodec, getReduceEventDecoder, getReduceEventEncoder, getReduceOrderInstruction, getReduceOrderInstructionDataCodec, getReduceOrderInstructionDataDecoder, getReduceOrderInstructionDataEncoder, getReduceOrderParamsCodec, getReduceOrderParamsDecoder, getReduceOrderParamsEncoder, getReduceOrderWithFreeFundsInstruction, getReduceOrderWithFreeFundsInstructionDataCodec, getReduceOrderWithFreeFundsInstructionDataDecoder, getReduceOrderWithFreeFundsInstructionDataEncoder, getRequestSeatAuthorizedInstruction, getRequestSeatAuthorizedInstructionDataCodec, getRequestSeatAuthorizedInstructionDataDecoder, getRequestSeatAuthorizedInstructionDataEncoder, getRequestSeatInstruction, getRequestSeatInstructionDataCodec, getRequestSeatInstructionDataDecoder, getRequestSeatInstructionDataEncoder, getSeatApprovalStatusCodec, getSeatApprovalStatusDecoder, getSeatApprovalStatusEncoder, getSeatCodec, getSeatDecoder, getSeatEncoder, getSelfTradeBehaviorCodec, getSelfTradeBehaviorDecoder, getSelfTradeBehaviorEncoder, getSideCodec, getSideDecoder, getSideEncoder, getSwapInstruction, getSwapInstructionDataCodec, getSwapInstructionDataDecoder, getSwapInstructionDataEncoder, getSwapWithFreeFundsInstruction, getSwapWithFreeFundsInstructionDataCodec, getSwapWithFreeFundsInstructionDataDecoder, getSwapWithFreeFundsInstructionDataEncoder, getTimeInForceEventCodec, getTimeInForceEventDecoder, getTimeInForceEventEncoder, getTokenParamsCodec, getTokenParamsDecoder, getTokenParamsEncoder, getWithdrawFundsInstruction, getWithdrawFundsInstructionDataCodec, getWithdrawFundsInstructionDataDecoder, getWithdrawFundsInstructionDataEncoder, identifyPhoenixV1Instruction, isOrderPacket, isPhoenixMarketEvent, orderPacket, parseCancelAllOrdersInstruction, parseCancelAllOrdersWithFreeFundsInstruction, parseCancelMultipleOrdersByIdInstruction, parseCancelMultipleOrdersByIdWithFreeFundsInstruction, parseCancelUpToInstruction, parseCancelUpToWithFreeFundsInstruction, parseChangeFeeRecipientInstruction, parseChangeMarketStatusInstruction, parseChangeSeatStatusInstruction, parseClaimAuthorityInstruction, parseCollectFeesInstruction, parseDepositFundsInstruction, parseEvictSeatInstruction, parseForceCancelOrdersInstruction, parseInitializeMarketInstruction, parseLogInstruction, parseNameSuccessorInstruction, parsePlaceLimitOrderInstruction, parsePlaceLimitOrderWithFreeFundsInstruction, parsePlaceMultiplePostOnlyOrdersInstruction, parsePlaceMultiplePostOnlyOrdersWithFreeFundsInstruction, parseReduceOrderInstruction, parseReduceOrderWithFreeFundsInstruction, parseRequestSeatAuthorizedInstruction, parseRequestSeatInstruction, parseSwapInstruction, parseSwapWithFreeFundsInstruction, parseWithdrawFundsInstruction, phoenixMarketEvent };
//# sourceMappingURL=index.mjs.map
//# sourceMappingURL=index.mjs.map